TargetOperatorExtensions Module
Functions and values
| Function or value |
Description
|
Full Usage:
x <==? y
Parameters:
string
y : string list
Returns: string
|
All dependencies in y must occur before x, but x does not depend on any of y. ie it defines all of y as soft dependencies of x Returns x
|
Full Usage:
x <?=? y
Parameters:
string
y : (string * bool) list
Returns: string
|
For each target in y, they are dependent on x if the condition is true. Returns x
|
Full Usage:
x ===> y
Parameters:
string
y : string list
|
|
Full Usage:
x ?==> y
Parameters:
string
y : string list
Returns: string
|
All dependencies in y depend on x as a soft dependency Returns x
|
Full Usage:
x ?=?> y
Parameters:
string
y : (string * bool) list
Returns: string
|
x is a dependent of any of y if their condition is true returns x
|