Logo Xantham

ArenaInterner Type

Lazily-resolved object graph view of a DecodedResult. Following a reference forces a Lazy<ResolvedType>, materialising a node on demand. Cycles are broken by lazy boundaries (construction never forces outgoing lazies). Exports are shelled eagerly; nested types are deferred.

Record fields

Record Field Description

ExportMap

Full Usage: ExportMap

Field type: Map<string, ResolvedExport list>

Map from source module path to the list of resolved exports declared in that module.

Field type: Map<string, ResolvedExport list>

Graph

Full Usage: Graph

Field type: Lazy<Graph>

WARNING: Evaluation of the graph can be expensive.
It is useful only when used in combination with the resolve type and resolve export dictionaries to handle dependencies correctly.

Field type: Lazy<Graph>

ResolveExport

Full Usage: ResolveExport

Field type: TypeKey -> Result<ResolvedExport, ResolvedType>

Resolve a TypeKey to a if it identifies an exported declaration; otherwise return the structural type as Error.

Field type: TypeKey -> Result<ResolvedExport, ResolvedType>

ResolveType

Full Usage: ResolveType

Field type: TypeKey -> ResolvedType

Resolve a TypeKey to a structural .

Field type: TypeKey -> ResolvedType

ResolvedExports

Full Usage: ResolvedExports

Field type: Dictionary<TypeKey, ResolvedExport>

Cache of all resolved export declarations keyed by their TypeKey.

Field type: Dictionary<TypeKey, ResolvedExport>

ResolvedTypes

Full Usage: ResolvedTypes

Field type: Dictionary<TypeKey, ResolvedType>

Cache of all resolved structural types keyed by their TypeKey.

Field type: Dictionary<TypeKey, ResolvedType>

Type something to start searching.