Logo Xantham

LazyContainer<'RawData, 'LazyResult> Type

Pairing of raw input data (, typically a TypeKey) with a lazily computed resolved value (). Used to defer resolution of cyclic dependencies in the type graph.

Record fields

Record Field Description

Data

Full Usage: Data

Field type: 'RawData

The raw input value (typically a TypeKey) that produced the lazy result.

Field type: 'RawData

Result

Full Usage: Result

Field type: Lazy<'LazyResult>

The lazy resolution of the raw data into a richer object graph value.

Field type: Lazy<'LazyResult>

Instance members

Instance member Description

this.IsValueCreated

Full Usage: this.IsValueCreated

Returns: bool
Modifiers: inline
Returns: bool

this.Raw

Full Usage: this.Raw

Returns: 'RawData
Modifiers: inline
Returns: 'RawData

this.Value

Full Usage: this.Value

Returns: 'LazyResult
Modifiers: inline

Force and return the lazy result.

Returns: 'LazyResult

Static members

Static member Description

LazyContainer.CreateFromValue(value)

Full Usage: LazyContainer.CreateFromValue(value)

Parameters:
    value : 'LazyResult

Returns: LazyContainer<'RawData, 'LazyResult>
Modifiers: inline
value : 'LazyResult
Returns: LazyContainer<'RawData, 'LazyResult>

LazyContainer.CreateLazyTypeKeyDummy(value)

Full Usage: LazyContainer.CreateLazyTypeKeyDummy(value)

Parameters:
    value : Lazy<'LazyResult>

Returns: LazyContainer<TypeKey, 'LazyResult>
value : Lazy<'LazyResult>
Returns: LazyContainer<TypeKey, 'LazyResult>

LazyContainer.CreateTypeKeyDummy(value)

Full Usage: LazyContainer.CreateTypeKeyDummy(value)

Parameters:
    value : 'LazyResult

Returns: LazyContainer<TypeKey, 'LazyResult>
value : 'LazyResult
Returns: LazyContainer<TypeKey, 'LazyResult>

LazyContainer.DummyTypeKey

Full Usage: LazyContainer.DummyTypeKey

Returns: int
Modifiers: inline
Returns: int

Type something to start searching.