QualifiedNamePartDiagnostic Type
Bit flags describing structural anomalies in a single segment of a fully qualified TypeScript name (e.g. embedded quotation marks, slashes, or periods).
Record fields
| Record Field |
Description
|
|
|
|
|
|
|
Bit flags describing structural anomalies in a single segment of a fully qualified TypeScript name (e.g. embedded quotation marks, slashes, or periods).
| Record Field |
Description
|
|
|
|
|
|
|