modulename Type
Measure to signify the name is modified to represent the module interface. This is used to distinguish between the module interface and the module itself.
Measure to signify the name is modified to represent the module interface. This is used to distinguish between the module interface and the module itself.