Logo Xantham

DecodedResult Type

Final shape returned by Decoder.read/Decoder.readWithSettings. Contains all decoded type, export, and module information from a Xantham JSON file in a form suitable for downstream generators.

Record fields

Record Field Description

ExportMap

Full Usage: ExportMap

Field type: ExportMap

Mapping from source module path to the set of TypeKeys exported by it.

Field type: ExportMap

ExportTypeMap

Full Usage: ExportTypeMap

Field type: ExportTypeMap

All exported declarations, keyed by TypeKey.

Field type: ExportTypeMap

LibEsExports

Full Usage: LibEsExports

Field type: TypeKey list

The TypeKeys belonging to the TypeScript lib.es* standard library.

Field type: TypeKey list

TopLevelExports

Full Usage: TopLevelExports

Field type: TypeKey list

The TypeKeys of declarations exported at the top level of the input.

Field type: TypeKey list

TypeMap

Full Usage: TypeMap

Field type: TypeMap

All structural types referenced anywhere in the source, keyed by TypeKey.

Field type: TypeMap

Type something to start searching.