Logo Xantham

Decoder Module

Types

Type Description

Settings

Settings for the Decoder.

Functions and values

Function or value Description

read fileName

Full Usage: read fileName

Parameters:
    fileName : string

Returns: Result<DecodedResult, string>

Decode a xantham produced .json file. This is a proxy function that creates a Settings object using the default values and the supplied fileName which is then passed to readWithSettings.

fileName : string
Returns: Result<DecodedResult, string>

readWithSettings settings

Full Usage: readWithSettings settings

Parameters:
Returns: Result<DecodedResult, string>

Decode a xantham produced .json file with the settings provided.

settings : Settings
Returns: Result<DecodedResult, string>

Type something to start searching.