Logo Xantham

Settings Type

Settings for the Decoder.

Record fields

Record Field Description

Compress

Full Usage: Compress

Field type: bool

Whether to compress the output TypeMap before passing to consumers. Defaults to true.

Field type: bool

InputFile

Full Usage: InputFile

Field type: string

The path to the .json file to decode.

Field type: string

PerformHealthCheck

Full Usage: PerformHealthCheck

Field type: bool

Whether to perform a health check on the decoded data and determine if there are any missing or dangling TypeKeys. Defaults to true in debug builds.

Field type: bool

Sanitize

Full Usage: Sanitize

Field type: bool

Whether to sanitize the typemap by replacing cyclical keys with obj. Defaults to true.

Field type: bool

Static members

Static member Description

Settings.Create(inputFile, ?performHealthCheck, ?compress, ?sanitize)

Full Usage: Settings.Create(inputFile, ?performHealthCheck, ?compress, ?sanitize)

Parameters:
    inputFile : string
    ?performHealthCheck : bool
    ?compress : bool
    ?sanitize : bool

Returns: Settings
inputFile : string
?performHealthCheck : bool
?compress : bool
?sanitize : bool
Returns: Settings

Type something to start searching.