Logo Xantham

Name Type

Utility type for working with names or manipulating the names of types and members while preserving the original source.

Union cases

Union case Description

Modified(original, modified)

Full Usage: Modified(original, modified)

Parameters:
    original : string
    modified : string

original : string
modified : string

Source original

Full Usage: Source original

Parameters:
    original : string

original : string

Instance members

Instance member Description

this.IsModified

Full Usage: this.IsModified

Returns: bool
Returns: bool

this.IsSource

Full Usage: this.IsSource

Returns: bool
Returns: bool

this.ValueOrModified

Full Usage: this.ValueOrModified

Returns: string

The modified string if the name has been modified; otherwise the original source string.

Returns: string

this.ValueOrSource

Full Usage: this.ValueOrSource

Returns: string

The original source string regardless of whether the name has been modified.

Returns: string

Static members

Static member Description

Name.Create(original, modified)

Full Usage: Name.Create(original, modified)

Parameters:
    original : string
    modified : string

Returns: Name

Create a Modified name from explicit original and modified strings.

original : string
modified : string
Returns: Name

Name.Create(value)

Full Usage: Name.Create(value)

Parameters:
    value : string

Returns: Name

Create an unmodified Source name from the given string. No normalization is applied.

value : string
Returns: Name

Name.CreateModified(original, modified)

Full Usage: Name.CreateModified(original, modified)

Parameters:
    original : string
    modified : string

Returns: Name

Create a Modified name from explicit original and modified strings.

original : string
modified : string
Returns: Name

Type something to start searching.