Logo Xantham

Name Module

Nested modules

Modules Description

Camel

Provides means for working with Camel case measure annotated names directly.

Case

Provides some equivalency functions for working with Names that have measures.

Module

Provides means for working with Module measure annotated names directly.

Normalization

Pascal

Provides means for working with Pascal case measure annotated names directly.

Typar

Provides means for working with Typar measure annotated names directly.

Functions and values

Function or value Description

camelCase name

Full Usage: camelCase name

Parameters:
Returns: Name

Applies camel casing to the name.

Backticks are removed prior to applying casing. Normalization is reapplied after casing is applied.

name : Name
Returns: Name

capitalize name

Full Usage: capitalize name

Parameters:
Returns: Name

Capitalizes the name.

Backticks are removed prior to applying casing. Normalization is reapplied after casing is applied.

name : Name
Returns: Name

create value

Full Usage: create value

Parameters:
    value : string

Returns: Name

Creates a Name from a string. Will automatically normalize the name with backticks if required.. Use the static member Create if you don't want automatic normalization.

value : string
Returns: Name

createModified original modified

Full Usage: createModified original modified

Parameters:
    original : string
    modified : string

Returns: Name
Modifiers: inline

Creates a modified Name DU.

original : string
modified : string
Returns: Name

map f name

Full Usage: map f name

Parameters:
    f : string -> string -
    name : Name -

Returns: Name

Map a function over the current (modified or original if unmodified) name.

If the output matches the original, then you will receive a Name.Source case instead of a Name.Modified case, even if it was Modified before.

f : string -> string

name : Name

Returns: Name

mapModified f name

Full Usage: mapModified f name

Parameters:
    f : string -> string -
    name : Name -

Returns: Name

Map a function over the modified name. Does not apply if the name is not modified.

f : string -> string

name : Name

Returns: Name

mapSource f name

Full Usage: mapSource f name

Parameters:
    f : string -> string -
    name : Name -

Returns: Name

Map a function over the original source name.

If the output differs from the original, you will receive a Name.Modified case.

f : string -> string

name : Name

Returns: Name

mapToModuleName name

Full Usage: mapToModuleName name

Parameters:
Returns: Name

Pascal cases the name, and prefixes with I.

Backticks are removed prior to applying casing. Normalization is reapplied after casing is applied.

name : Name
Returns: Name

normalize name

Full Usage: normalize name

Parameters:
Returns: Name

Normalizes the name by adding backticks if needed

name : Name
Returns: Name

normalizeForEnumCase

Full Usage: normalizeForEnumCase

Returns: Name -> Name

Normalizes name for enum cases. Uses PascalCase.

Returns: Name -> Name

normalizeForMethod

Full Usage: normalizeForMethod

Returns: Name -> Name

Normalizes name for methods. Uses camelCase.

Returns: Name -> Name

normalizeForParameter

Full Usage: normalizeForParameter

Returns: Name -> Name

Normalizes name for parameters. Uses camelCase.

Returns: Name -> Name

normalizeForProperty

Full Usage: normalizeForProperty

Returns: Name -> Name

Normalizes name for properties. Uses camelCase.

Returns: Name -> Name

normalizeForType

Full Usage: normalizeForType

Returns: Name -> Name

Normalizes name for types. Uses PascalCase.

Returns: Name -> Name

normalizeForTypeParameter

Full Usage: normalizeForTypeParameter

Returns: Name -> Name

Pascal cases the name, and prefixes with a single quote.

Backticks are removed prior to applying casing. Normalization is reapplied after casing is applied.

Returns: Name -> Name

pascalCase name

Full Usage: pascalCase name

Parameters:
Returns: Name

Applies Pascal Casing to the name.

Backticks are removed prior to applying casing. Normalization is reapplied after casing is applied.

If the name was modified, then the function is applied against the Modified value.

name : Name
Returns: Name

sourceCamelCase name

Full Usage: sourceCamelCase name

Parameters:
Returns: Name

Applies camel casing to the source name.

Backticks are removed prior to applying casing. Normalization is reapplied after casing is applied.

The function is applied to the source string, even if the name is modified

name : Name
Returns: Name

sourceCapitalize name

Full Usage: sourceCapitalize name

Parameters:
Returns: Name

Capitalizes the source name.

Backticks are removed prior to applying casing. Normalization is reapplied after casing is applied.

The function is applied to the source string, even if the name is modified

name : Name
Returns: Name

sourceMapToModuleName name

Full Usage: sourceMapToModuleName name

Parameters:
Returns: Name

Pascal cases the source name, and then prefixes with I.

Backticks are removed prior to applying casing. Normalization is reapplied after casing is applied.

The function is applied to the source string, even if the name is modified

name : Name
Returns: Name

sourceNormalizeForEnumCase

Full Usage: sourceNormalizeForEnumCase

Returns: Name -> Name

Normalizes name for enum cases. Uses PascalCase.

Returns: Name -> Name

sourceNormalizeForMethod

Full Usage: sourceNormalizeForMethod

Returns: Name -> Name

Normalizes name for methods. Uses camelCase.

Returns: Name -> Name

sourceNormalizeForParameter

Full Usage: sourceNormalizeForParameter

Returns: Name -> Name

Normalizes name for parameters. Uses camelCase.

Returns: Name -> Name

sourceNormalizeForProperty

Full Usage: sourceNormalizeForProperty

Returns: Name -> Name

Normalizes name for properties. Uses camelCase.

Returns: Name -> Name

sourceNormalizeForType

Full Usage: sourceNormalizeForType

Returns: Name -> Name

Normalizes name for types. Uses PascalCase.

Returns: Name -> Name

sourceNormalizeForTypeParameter

Full Usage: sourceNormalizeForTypeParameter

Returns: Name -> Name

Pascal cases the source name, and prefixes with a single quote.

Backticks are removed prior to applying casing. Normalization is reapplied after casing is applied.

The function is applied to the source string, even if the name is modified

Returns: Name -> Name

sourcePascalCase name

Full Usage: sourcePascalCase name

Parameters:
Returns: Name

Applies Pascal Casing to the source name.

Backticks are removed prior to applying casing. Normalization is reapplied after casing is applied.

The function is applied to the source string, even if the name is modified

name : Name
Returns: Name

valueOrModified _arg1

Full Usage: valueOrModified _arg1

Parameters:
Returns: string

Retrieves the modified value for a name if it exists; otherwise returns the original source value.

_arg1 : Name
Returns: string

valueOrSource _arg1

Full Usage: valueOrSource _arg1

Parameters:
Returns: string

Retrieves the original source value for a name.

_arg1 : Name
Returns: string

Type something to start searching.