Logo Xantham

Runtime Module

Types and nested modules

Type/Module Description

Map

Settings

Runtime configuration for a XanthamTree. Wraps the underlying Decoder.Settings and may be extended with runtime-only options in the future.

XanthamTree

In-memory representation of a decoded Xantham JSON file, optimised for generator access. Holds frozen lookups for types, exports, top-level declarations, and provides lazy access to the resolved object graph (ArenaInterner) and a dependency graph.

Functions and values

Function or value Description

create fileName

Full Usage: create fileName

Parameters:
    fileName : string - Path to the input JSON file.

Returns: XanthamTree

Create a XanthamTree from the given Xantham JSON file path using default decoder settings.

fileName : string

Path to the input JSON file.

Returns: XanthamTree

createWith fn fileName

Full Usage: createWith fn fileName

Parameters:
    fn : Settings -> Settings - Transform applied to the default settings.
    fileName : string - Path to the input JSON file.

Returns: XanthamTree

Create a XanthamTree from the given Xantham JSON file path with a transformation function applied to the default Settings.

fn : Settings -> Settings

Transform applied to the default settings.

fileName : string

Path to the input JSON file.

Returns: XanthamTree

Type something to start searching.