Logo Xantham

Settings Type

Runtime configuration for a XanthamTree. Wraps the underlying Decoder.Settings and may be extended with runtime-only options in the future.

Record fields

Record Field Description

Decoder

Full Usage: Decoder

Field type: Settings

Decoder-layer settings controlling how the input JSON is read.

Field type: Settings

Static members

Static member Description

Settings.Create(fn) (fileName)

Full Usage: Settings.Create(fn) (fileName)

Parameters:
    fn : Settings -> Settings - Transform applied to the default settings.
    fileName : string - Path to the input JSON file.

Returns: Settings

Create Settings for the given input file and apply a transformation function to customise the defaults.

fn : Settings -> Settings

Transform applied to the default settings.

fileName : string

Path to the input JSON file.

Returns: Settings

Settings.Init(filePath)

Full Usage: Settings.Init(filePath)

Parameters:
    filePath : string

Returns: Settings

Create default Settings for the given input file path.

filePath : string
Returns: Settings

Type something to start searching.