Logo Xantham

DependencyRule Type

A [dependencies."pkg"] rule for a reached package not bound as a library.

Record fields

Record Field Description

Modules

Full Usage: Modules

Field type: string list

The rendered top-level module names this package owns, when they differ from the package-name derivation — e.g. json-schema-typed also surfaces its declared TS namespace as a `JsonSchema` module. Empty = derivation only.

Field type: string list

Package

Full Usage: Package

Field type: string
Field type: string

Policy

Full Usage: Policy

Field type: DependencyPolicy
Field type: DependencyPolicy

Type something to start searching.