PropertyRecord<'T, 'K> Type
A record implementation that allows you to access properties using a property key
Instance members
| Instance member |
Description
|
|
|
A record implementation that allows you to access properties using a property key
| Instance member |
Description
|
|
|