Logo Xantham

ExportTypeIds Type

The type ids an export resolves to. A symbol can be both a type and a value (a class), so the two are separate fields rather than one.

Record fields

Record Field Description

Declared

Full Usage: Declared

Field type: int option
Field type: int option

Value

Full Usage: Value

Field type: int option
Field type: int option

Type something to start searching.