Logo Xantham

TypedNameRender Module

Functions and values

Function or value Description

renderAbstract ctx typedName

Full Usage: renderAbstract ctx typedName

Parameters:
Returns: WidgetBuilder<MemberDefn>

renderAbstractImpl withOption ctx typedName

Full Usage: renderAbstractImpl withOption ctx typedName

Parameters:
Returns: WidgetBuilder<MemberDefn>
withOption : bool
ctx : GeneratorContext
typedName : TypedNameRender
Returns: WidgetBuilder<MemberDefn>

renderAbstractNoOption ctx typedName

Full Usage: renderAbstractNoOption ctx typedName

Parameters:
Returns: WidgetBuilder<MemberDefn>

renderAsNamedType ctx typedName

Full Usage: renderAsNamedType ctx typedName

Parameters:
Returns: WidgetBuilder<Type>

Render a typed name render as a type signature, with the optionality being rendered on the type.

ctx : GeneratorContext

typedName : TypedNameRender

Returns: WidgetBuilder<Type>

renderAsNamedTypeImpl withOption ctx typedName

Full Usage: renderAsNamedTypeImpl withOption ctx typedName

Parameters:
Returns: WidgetBuilder<Type>

Renders a typed name as a type signature (ie, a named type parameter in a delegate or abstract member). You can enable or disable the rendering of the optionality in the type, or in the name instead using the withOption switch

withOption : bool

ctx : GeneratorContext

typedName : TypedNameRender

Returns: WidgetBuilder<Type>

renderAsNamedTypeWithOptionName ctx typedName

Full Usage: renderAsNamedTypeWithOptionName ctx typedName

Parameters:
Returns: WidgetBuilder<Type>

Render a typed name render as a type signature, with the option name rendered instead of wrapping the type with option.

ctx : GeneratorContext

typedName : TypedNameRender

Returns: WidgetBuilder<Type>

renderAsPattern ctx typedName

Full Usage: renderAsPattern ctx typedName

Parameters:
Returns: WidgetBuilder<Pattern>

Renders a typed name as a parameter pattern. Any optionality in the type ref or the type name render will result in the type being wrapped in option.

ctx : GeneratorContext

typedName : TypedNameRender

Returns: WidgetBuilder<Pattern>

renderAsPatternWithOptionName ctx typedName

Full Usage: renderAsPatternWithOptionName ctx typedName

Parameters:
Returns: WidgetBuilder<Pattern>

Renders a typed name as a parameter pattern. Will route any nullability in the typed name render or the type ref to the parameter name.

ctx : GeneratorContext

typedName : TypedNameRender

Returns: WidgetBuilder<Pattern>

renderBinding ctx typedName

Full Usage: renderBinding ctx typedName

Parameters:
Returns: WidgetBuilder<BindingNode>

renderMember ctx typedName

Full Usage: renderMember ctx typedName

Parameters:
Returns: WidgetBuilder<MemberDefn>

renderTypeOnly ctx typedName

Full Usage: renderTypeOnly ctx typedName

Parameters:
Returns: WidgetBuilder<Type>

renderValMember ctx typedName anchorPath

Full Usage: renderValMember ctx typedName anchorPath

Parameters:
Returns: WidgetBuilder<MemberDefn>
Type parameters: 'a
ctx : GeneratorContext
typedName : TypedNameRender
anchorPath : 'a
Returns: WidgetBuilder<MemberDefn>

Type something to start searching.