Logo Xantham

NamePath Module

Types and nested modules

Type/Module Description

AnchorPath (Module)

MemberLikePath (Module)

MemberPath (Module)

ModuleLikePath (Module)

ModulePath (Module)

ParameterLikePath (Module)

ParameterPath (Module)

Path (Module)

QualifiedName (Module)

QualifiedNamePart (Module)

TransientMemberPath (Module)

TransientModulePath (Module)

TransientParameterPath (Module)

TransientPath (Module)

TransientTypeParameterPath

TransientTypePath (Module)

TypeLikePath (Module)

TypeParamLikePath (Module)

TypeParamPath (Module)

TypePath (Module)

AnchorPath (Type)

MemberLikePath (Type)

MemberPath (Type)

MemberPathParent

ModuleLikePath (Type)

ModulePath (Type)

ParameterLikePath (Type)

ParameterPath (Type)

Path (Type)

PathBuilder

Builder for constructing paths with easily identifiable syntax (originally made for spec testing, but may be a useful abstraction for consumers who need to create paths for injected types or other purposes).

All concrete paths are preceded by a single _, while transient paths are preceded and followed by _.
Therefor making a concrete path would be:

 _module "Root"; _module "Module"; _type "Type"
And a transient path would be:
 _module_ "Root"; _type_ "Type"
If you do not pass a string to the transient builder, it will be anchored.
 _type_ // TransientTypePath.Anchored
 _type_ "Type" // TransientTypePath.AnchoredAndMoored "Type"
 _module_ "Module"; _type_ "Type" // TransientTypePath.Moored(TransientModulePath.AnchoredAndMoored "Module", "Type")

QualifiedName (Type)

QualifiedNamePart (Type)

TransientMemberPath (Type)

TransientModulePath (Type)

TransientParameterPath (Type)

TransientPath (Type)

TransientTypePath (Type)

TypeLikePath (Type)

TypeParamLikePath (Type)

TypeParamPath (Type)

TypeParamPathParent

TypePath (Type)

Functions and values

Function or value Description

pathCe

Full Usage: pathCe

Returns: PathBuilder

Builder for constructing paths with easily identifiable syntax (originally made for spec testing, but may be a useful abstraction for consumers who need to create paths for injected types or other purposes).

All concrete paths are preceded by a single _, while transient paths are preceded and followed by _.
Therefor making a concrete path would be:

 _module "Root"; _module "Module"; _type "Type"
And a transient path would be:
 _module_ "Root"; _type_ "Type"
If you do not pass a string to the transient builder, it will be anchored.
 _type_ // TransientTypePath.Anchored
 _type_ "Type" // TransientTypePath.AnchoredAndMoored "Type"
 _module_ "Module"; _type_ "Type" // TransientTypePath.Moored(TransientModulePath.AnchoredAndMoored "Module", "Type")

Returns: PathBuilder

Type something to start searching.