Logo Xantham

PathBuilder Type

Builder for constructing paths with easily identifiable syntax (originally made for spec testing, but may be a useful abstraction for consumers who need to create paths for injected types or other purposes).

All concrete paths are preceded by a single _, while transient paths are preceded and followed by _.
Therefor making a concrete path would be:

 _module "Root"; _module "Module"; _type "Type"
And a transient path would be:
 _module_ "Root"; _type_ "Type"
If you do not pass a string to the transient builder, it will be anchored.
 _type_ // TransientTypePath.Anchored
 _type_ "Type" // TransientTypePath.AnchoredAndMoored "Type"
 _module_ "Module"; _type_ "Type" // TransientTypePath.Moored(TransientModulePath.AnchoredAndMoored "Module", "Type")

Constructors

Constructor Description

PathBuilder()

Full Usage: PathBuilder()

Returns: PathBuilder
Returns: PathBuilder

Instance members

Instance member Description

asAnchorPath

Full Usage: asAnchorPath

Returns: AnchorPath
Modifiers: inline
Type parameters: ^a (requires (static member Create : ^a -> Xantham.Generator.NamePath.AnchorPath))
Returns: AnchorPath

asPath

Full Usage: asPath

Returns: Path
Modifiers: inline
Type parameters: ^a, ^b (requires (static member Create : ^a -> ^b) and (static member Create : ^b -> Xantham.Generator.NamePath.Path))
Returns: Path

asTransientPath

Full Usage: asTransientPath

Returns: TransientPath
Modifiers: inline
Type parameters: ^a (requires (static member Create : ^a -> Xantham.Generator.NamePath.TransientPath))
Returns: TransientPath

this.Combine

Full Usage: this.Combine

Parameters:
Returns: TransientParameterPath
Modifiers: inline

this.Combine

Full Usage: this.Combine

Parameters:
Returns: TransientMemberPath
Modifiers: inline
a : TransientTypePath
b : string
Returns: TransientMemberPath

this.Combine

Full Usage: this.Combine

Parameters:
Returns: TransientModulePath
Modifiers: inline
a : TransientModulePath
b : string
Returns: TransientModulePath

this.Combine

Full Usage: this.Combine

Parameters:
Returns: TypeParamPath
Modifiers: inline

this.Combine

Full Usage: this.Combine

Parameters:
Returns: TypeParamPath
Modifiers: inline

this.Combine

Full Usage: this.Combine

Parameters:
Returns: TypeParamPath
Modifiers: inline

this.Combine

Full Usage: this.Combine

Parameters:
Returns: ParameterPath
Modifiers: inline
a : MemberPath
b : string
Returns: ParameterPath

this.Combine

Full Usage: this.Combine

Parameters:
Returns: MemberPath
Modifiers: inline
a : TypePath
b : string
Returns: MemberPath

this.Combine

Full Usage: this.Combine

Parameters:
    a : string
    b : string

Returns: ModulePath
Modifiers: inline
a : string
b : string
Returns: ModulePath

this.Combine

Full Usage: this.Combine

Parameters:
Returns: ModulePath
Modifiers: inline
a : ModulePath
b : string
Returns: ModulePath

this.Combine

Full Usage: this.Combine

Parameters:
    a : 'a
    b : unit

Returns: 'a
Modifiers: inline
Type parameters: 'a
a : 'a
b : unit
Returns: 'a

this.Delay

Full Usage: this.Delay

Parameters:
    a : unit -> 'a

Returns: 'a
Modifiers: inline
Type parameters: 'a
a : unit -> 'a
Returns: 'a

this.For

Full Usage: this.For

Parameters:
Returns: ModulePath
Modifiers: inline
a : ModulePath
b : unit -> string
Returns: ModulePath

_member b

Full Usage: _member b

Parameters:
    b : string

Returns: MemberPath
Modifiers: inline
b : string
Returns: MemberPath

_member b

Full Usage: _member b

Parameters:
    b : string

Returns: MemberPath
Modifiers: inline
b : string
Returns: MemberPath

_module b

Full Usage: _module b

Parameters:
    b : string

Returns: ModulePath
Modifiers: inline
b : string
Returns: ModulePath

_module b

Full Usage: _module b

Parameters:
    b : string

Returns: ModulePath
Modifiers: inline
b : string
Returns: ModulePath

_parameter b

Full Usage: _parameter b

Parameters:
    b : string

Returns: ParameterPath
Modifiers: inline
b : string
Returns: ParameterPath

_member_ b

Full Usage: _member_ b

Parameters:
    b : string

Returns: TransientMemberPath
Modifiers: inline
b : string
Returns: TransientMemberPath

_member_ b

Full Usage: _member_ b

Parameters:
    b : string

Returns: TransientMemberPath
Modifiers: inline
b : string
Returns: TransientMemberPath

_member_

Full Usage: _member_

Returns: TransientMemberPath
Modifiers: inline

_module_

Full Usage: _module_

Returns: TransientModulePath
Modifiers: inline

_module_ b

Full Usage: _module_ b

Parameters:
    b : string

Returns: TransientModulePath
Modifiers: inline
b : string
Returns: TransientModulePath

_module_ b

Full Usage: _module_ b

Parameters:
    b : string

Returns: TransientModulePath
Modifiers: inline
b : string
Returns: TransientModulePath

_module_ b

Full Usage: _module_ b

Parameters:
    b : string

Returns: TransientModulePath
Modifiers: inline
b : string
Returns: TransientModulePath

_parameter_ b

Full Usage: _parameter_ b

Parameters:
    b : string

Returns: TransientParameterPath
Modifiers: inline
b : string
Returns: TransientParameterPath

_parameter_ b

Full Usage: _parameter_ b

Parameters:
    b : string

Returns: TransientParameterPath
Modifiers: inline
b : string
Returns: TransientParameterPath

_parameter_

Full Usage: _parameter_

Returns: TransientParameterPath
Modifiers: inline

_type_ b

Full Usage: _type_ b

Parameters:
    b : string

Returns: TransientTypePath
Modifiers: inline
b : string
Returns: TransientTypePath

_type_ b

Full Usage: _type_ b

Parameters:
    b : string

Returns: TransientTypePath
Modifiers: inline
b : string
Returns: TransientTypePath

_type_

Full Usage: _type_

Returns: TransientTypePath
Modifiers: inline

_type b

Full Usage: _type b

Parameters:
    b : string

Returns: TypePath
Modifiers: inline
b : string
Returns: TypePath

_typar b

Full Usage: _typar b

Parameters:
    b : string

Returns: TypeParamPath
Modifiers: inline
b : string
Returns: TypeParamPath

_typar b

Full Usage: _typar b

Parameters:
    b : string

Returns: TypeParamPath
Modifiers: inline
b : string
Returns: TypeParamPath

_typar b

Full Usage: _typar b

Parameters:
    b : string

Returns: TypeParamPath
Modifiers: inline
b : string
Returns: TypeParamPath

this.Run

Full Usage: this.Run

Parameters:
    a : 'a

Returns: 'a
Modifiers: inline
Type parameters: 'a
a : 'a
Returns: 'a

this.Yield

Full Usage: this.Yield

Parameters:
    n : string

Returns: string
Modifiers: inline
n : string
Returns: string

this.Yield

Full Usage: this.Yield

Parameters:
Returns: Path
Modifiers: inline
n : Path
Returns: Path

this.Yield

Full Usage: this.Yield

Parameters:
Returns: TransientPath
Modifiers: inline

this.Yield

Full Usage: this.Yield

Parameters:
Returns: AnchorPath
Modifiers: inline
n : AnchorPath
Returns: AnchorPath

this.Yield

Full Usage: this.Yield

Parameters:
Returns: TransientParameterPath
Modifiers: inline

this.Yield

Full Usage: this.Yield

Parameters:
Returns: TransientMemberPath
Modifiers: inline

this.Yield

Full Usage: this.Yield

Parameters:
Returns: TransientModulePath
Modifiers: inline

this.Yield

Full Usage: this.Yield

Parameters:
Returns: TransientTypePath
Modifiers: inline

this.Yield

Full Usage: this.Yield

Parameters:
Returns: TypeParamPath
Modifiers: inline

this.Yield

Full Usage: this.Yield

Parameters:
Returns: ParameterPath
Modifiers: inline

this.Yield

Full Usage: this.Yield

Parameters:
Returns: MemberPath
Modifiers: inline
n : MemberPath
Returns: MemberPath

this.Yield

Full Usage: this.Yield

Parameters:
Returns: TypePath
Modifiers: inline
n : TypePath
Returns: TypePath

this.Yield

Full Usage: this.Yield

Parameters:
Returns: ModulePath
Modifiers: inline
n : ModulePath
Returns: ModulePath

this.Yield

Full Usage: this.Yield

Parameters:
    a : unit

Modifiers: inline
a : unit

this.Zero

Full Usage: this.Zero

Modifiers: inline

Type something to start searching.