Logo Xantham

RenderScopeStore Module

The strategy here is to force references being created with a contract that would recognise and register any transient type paths that are defined.

Nested modules

Modules Description

TypeRef

TypeRefAtom

TypeRefMolecule

TypeRefRender

Functions and values

Function or value Description

appendNameToPathContext scope name

Full Usage: appendNameToPathContext scope name

Parameters:
Returns: RenderScopeStore
Type parameters: 'u
scope : RenderScopeStore
name : Name<'u>
Returns: RenderScopeStore

appendStringToPathContext scope str

Full Usage: appendStringToPathContext scope str

Parameters:
Returns: RenderScopeStore
scope : RenderScopeStore
str : string
Returns: RenderScopeStore

create ()

Full Usage: create ()

Parameters:
    () : unit

Returns: RenderScopeStore
() : unit
Returns: RenderScopeStore

mapPathContext fn scope

Full Usage: mapPathContext fn scope

Parameters:
Returns: RenderScopeStore

tryAdd resolvedType transientTypePath scope

Full Usage: tryAdd resolvedType transientTypePath scope

Parameters:
resolvedType : ResolvedType
transientTypePath : TransientTypePath
scope : RenderScopeStore

Type something to start searching.