Logo Xantham

UnionBuilder Type

A builder for WidgetBuilder<Type>s that represent erased unions in Fable. It tracks the lengths of the unions it builds to ensure that we have all erased unions defined in the base set, otherwise we can generate our own.

Constructors

Constructor Description

UnionBuilder(maxLengthExisting)

Full Usage: UnionBuilder(maxLengthExisting)

Parameters:
    maxLengthExisting : int

Returns: UnionBuilder
maxLengthExisting : int
Returns: UnionBuilder

Instance members

Instance member Description

this.Combine

Full Usage: this.Combine

Parameters:
Returns: WidgetBuilder<Type> list
l : WidgetBuilder<Type> list
r : WidgetBuilder<Type> list
Returns: WidgetBuilder<Type> list

this.Delay

Full Usage: this.Delay

Parameters:
Returns: WidgetBuilder<Type> list
f : unit -> WidgetBuilder<Type> list
Returns: WidgetBuilder<Type> list

this.Run

Full Usage: this.Run

Parameters:
Returns: WidgetBuilder<Type>
state : WidgetBuilder<Type> list
Returns: WidgetBuilder<Type>

this.UnionLengths

Full Usage: this.UnionLengths

Returns: HashSet<int>
Returns: HashSet<int>

this.Yield

Full Usage: this.Yield

Parameters:
    value : string

Returns: WidgetBuilder<Type> list
value : string
Returns: WidgetBuilder<Type> list

this.Yield

Full Usage: this.Yield

Parameters:
Returns: WidgetBuilder<Type> list
value : WidgetBuilder<Type>
Returns: WidgetBuilder<Type> list

this.YieldFrom

Full Usage: this.YieldFrom

Parameters:
    value : string list

Returns: WidgetBuilder<Type> list
value : string list
Returns: WidgetBuilder<Type> list

this.YieldFrom

Full Usage: this.YieldFrom

Parameters:
Returns: WidgetBuilder<Type> list
value : WidgetBuilder<Type> list
Returns: WidgetBuilder<Type> list

Type something to start searching.