Logo Xantham

UnionBuilder Module

Functions and values

Function or value Description

erasedUnion

Full Usage: erasedUnion

Returns: UnionBuilder

Erased union builder to build WidgetBuilder<Type>s that represent erased unions in Fable. It tracks the lengths of the unions it builds to ensure that we have all erased unions defined in the base set, otherwise we can generate our own.

Returns: UnionBuilder

Type something to start searching.