Logo Xantham

InlinedTsTypeParameter Type

A tuple to be used by types which inline TsTypeParameters rather than referencing by TypeKey. The tuple is used to preserve information for the container type that inlines them.

Instance members

Instance member Description

this.Item1

Full Usage: this.Item1

Returns: TypeKey
Returns: TypeKey

this.Item2

Full Usage: this.Item2

Returns: TsTypeParameter
Returns: TsTypeParameter

Type something to start searching.