TsCallSignature Type
Represents a call signature in a type literal or interface.
Reflects: `CallSignatureDeclaration`.
interface FnLike { (x: number, y: number): number }
Record fields
| Record Field |
Description
|
|
|
|
|
|
Represents a call signature in a type literal or interface.
Reflects: `CallSignatureDeclaration`.
interface FnLike { (x: number, y: number): number }
| Record Field |
Description
|
|
|
|
|
|