Logo Xantham

TsFunction Type

Represents a top-level (or exported) function declaration with its type and generics. Reflects: `FunctionDeclaration` and its `Signature`. Example (TS): ```ts export function sum(a: T, b: T): T { return (a + b) as T } ```

Record fields

Record Field Description

Documentation

Full Usage: Documentation

Field type: TsComment list
Field type: TsComment list

FullyQualifiedName

Full Usage: FullyQualifiedName

Field type: string list
Field type: string list

IsDeclared

Full Usage: IsDeclared

Field type: bool
Field type: bool

Name

Full Usage: Name

Field type: string
Field type: string

Parameters

Full Usage: Parameters

Field type: TsParameter list
Field type: TsParameter list

SignatureKey

Full Usage: SignatureKey

Field type: TypeKey

The type key or signature key of the function's signature. This key should return a type literal with call signatures.

Field type: TypeKey

Full Usage: Source

Field type: string option
Field type: string option

Type

Full Usage: Type

Field type: TypeKey
Field type: TypeKey

TypeParameters

Full Usage: TypeParameters

Field type: InlinedTsTypeParameter list
Field type: InlinedTsTypeParameter list

Type something to start searching.