TsIndexAccessType Type
Represents an indexed access type, where a property type is selected by an index type.
Reflects: `IndexedAccessType`.
Example (TS):
```ts
type Foo
Represents an indexed access type, where a property type is selected by an index type.
Reflects: `IndexedAccessType`.
Example (TS):
```ts
type Foo