TsSubstitutionType Type
Represents a substitution type: a type parameter substituted with a concrete type under its constraint context. Reflects: `SubstitutionType` in the TS type system.
Represents a substitution type: a type parameter substituted with a concrete type under its constraint context. Reflects: `SubstitutionType` in the TS type system.