TsTypeParameter Type
Represents a generic type parameter with optional constraint and default.
Reflects: `TypeParameterDeclaration` and `TypeParameter` (constraint `extends`, default value).
type Box<T extends object = {}> = { value: T }
Represents a generic type parameter with optional constraint and default.
Reflects: `TypeParameterDeclaration` and `TypeParameter` (constraint `extends`, default value).
type Box<T extends object = {}> = { value: T }