Logo Xantham

TsTypeQuery Type

Represents a type query like `typeof Foo` or `typeof Foo.bar`. The type query is resolved to the type of the referenced entity.

The name is provided so that enum like type query unions can have names inferred from the query appropriately.
This is the cheapest schema representation.

Record fields

Record Field Description

FullyQualifiedName

Full Usage: FullyQualifiedName

Field type: string list
Field type: string list

Type

Full Usage: Type

Field type: TypeKey
Field type: TypeKey

Type something to start searching.