Logo Xantham

Accessors Module

Typed child and data access, one module per node type. These are the `AstNode` accessors with the argument and the result typed, which is the whole difference: `AstNode.IfStatement.thenStatement` will read slot 1 of anything you hand it, and `IfStatement.thenStatement` will not compile unless you hand it one.

Nested modules

Modules Description

ArrayLiteralExpression

Children of `ArrayLiteralExpression`.

ArrayTypeNode

Children of `ArrayTypeNode`.

ArrowFunction

Children of `ArrowFunction`.

AsExpression

Children of `AsExpression`.

AwaitExpression

Children of `AwaitExpression`.

BigIntLiteral

Data of `BigIntLiteral`, which has no children.

BinaryExpression

Children of `BinaryExpression`.

BindingElement

Children of `BindingElement`.

BindingPattern

Children of `BindingPattern`.

Block

Children of `Block`.

BreakStatement

Children of `BreakStatement`.

CallExpression

Children of `CallExpression`.

CallSignatureDeclaration

Children of `CallSignatureDeclaration`.

CaseBlock

Children of `CaseBlock`.

CaseOrDefaultClause

Children of `CaseOrDefaultClause`.

CatchClause

Children of `CatchClause`.

ClassDeclaration

Children of `ClassDeclaration`.

ClassExpression

Children of `ClassExpression`.

ClassStaticBlockDeclaration

Children of `ClassStaticBlockDeclaration`.

ComputedPropertyName

Children of `ComputedPropertyName`.

ConditionalExpression

Children of `ConditionalExpression`.

ConditionalTypeNode

Children of `ConditionalTypeNode`.

ConstructSignatureDeclaration

Children of `ConstructSignatureDeclaration`.

ConstructorDeclaration

Children of `ConstructorDeclaration`.

ConstructorTypeNode

Children of `ConstructorTypeNode`.

ContinueStatement

Children of `ContinueStatement`.

Decorator

Children of `Decorator`.

DeleteExpression

Children of `DeleteExpression`.

DoStatement

Children of `DoStatement`.

ElementAccessExpression

Children of `ElementAccessExpression`.

EnumDeclaration

Children of `EnumDeclaration`.

EnumMember

Children of `EnumMember`.

ExportAssignment

Children of `ExportAssignment`.

ExportDeclaration

Children of `ExportDeclaration`.

ExportSpecifier

Children of `ExportSpecifier`.

ExpressionStatement

Children of `ExpressionStatement`.

ExpressionWithTypeArguments

Children of `ExpressionWithTypeArguments`.

ExternalModuleReference

Children of `ExternalModuleReference`.

ForInOrOfStatement

Children of `ForInOrOfStatement`.

ForStatement

Children of `ForStatement`.

FunctionDeclaration

Children of `FunctionDeclaration`.

FunctionExpression

Children of `FunctionExpression`.

FunctionTypeNode

Children of `FunctionTypeNode`.

GetAccessorDeclaration

Children of `GetAccessorDeclaration`.

HeritageClause

Children of `HeritageClause`.

Identifier

Data of `Identifier`, which has no children.

IfStatement

Children of `IfStatement`.

ImportAttribute

Children of `ImportAttribute`.

ImportAttributes

Children of `ImportAttributes`.

ImportClause

Children of `ImportClause`.

ImportDeclaration

Children of `ImportDeclaration`.

ImportEqualsDeclaration

Children of `ImportEqualsDeclaration`.

ImportSpecifier

Children of `ImportSpecifier`.

ImportTypeNode

Children of `ImportTypeNode`.

IndexSignatureDeclaration

Children of `IndexSignatureDeclaration`.

IndexedAccessTypeNode

Children of `IndexedAccessTypeNode`.

InferTypeNode

Children of `InferTypeNode`.

InterfaceDeclaration

Children of `InterfaceDeclaration`.

IntersectionTypeNode

Children of `IntersectionTypeNode`.

JSDoc

Children of `JSDoc`.

JSDocAugmentsTag

Children of `JSDocAugmentsTag`.

JSDocCallbackTag

Children of `JSDocCallbackTag`.

JSDocDeprecatedTag

Children of `JSDocDeprecatedTag`.

JSDocImplementsTag

Children of `JSDocImplementsTag`.

JSDocImportTag

Children of `JSDocImportTag`.

JSDocLink

Children of `JSDocLink`.

JSDocLinkCode

Children of `JSDocLinkCode`.

JSDocLinkPlain

Children of `JSDocLinkPlain`.

JSDocNameReference

Children of `JSDocNameReference`.

JSDocNonNullableType

Children of `JSDocNonNullableType`.

JSDocNullableType

Children of `JSDocNullableType`.

JSDocOptionalType

Children of `JSDocOptionalType`.

JSDocOverloadTag

Children of `JSDocOverloadTag`.

JSDocOverrideTag

Children of `JSDocOverrideTag`.

JSDocParameterOrPropertyTag

Children of `JSDocParameterOrPropertyTag`.

JSDocPrivateTag

Children of `JSDocPrivateTag`.

JSDocProtectedTag

Children of `JSDocProtectedTag`.

JSDocPublicTag

Children of `JSDocPublicTag`.

JSDocReadonlyTag

Children of `JSDocReadonlyTag`.

JSDocReturnTag

Children of `JSDocReturnTag`.

JSDocSatisfiesTag

Children of `JSDocSatisfiesTag`.

JSDocSeeTag

Children of `JSDocSeeTag`.

JSDocSignature

Children of `JSDocSignature`.

JSDocTemplateTag

Children of `JSDocTemplateTag`.

JSDocText

Data of `JSDocText`, which has no children.

JSDocThisTag

Children of `JSDocThisTag`.

JSDocThrowsTag

Children of `JSDocThrowsTag`.

JSDocTypeExpression

Children of `JSDocTypeExpression`.

JSDocTypeLiteral

Children of `JSDocTypeLiteral`.

JSDocTypeTag

Children of `JSDocTypeTag`.

JSDocTypedefTag

Children of `JSDocTypedefTag`.

JSDocUnknownTag

Children of `JSDocUnknownTag`.

JSDocVariadicType

Children of `JSDocVariadicType`.

JsxAttribute

Children of `JsxAttribute`.

JsxAttributes

Children of `JsxAttributes`.

JsxClosingElement

Children of `JsxClosingElement`.

JsxElement

Children of `JsxElement`.

JsxExpression

Children of `JsxExpression`.

JsxFragment

Children of `JsxFragment`.

JsxNamespacedName

Children of `JsxNamespacedName`.

JsxOpeningElement

Children of `JsxOpeningElement`.

JsxSelfClosingElement

Children of `JsxSelfClosingElement`.

JsxSpreadAttribute

Children of `JsxSpreadAttribute`.

JsxText

Data of `JsxText`, which has no children.

LabeledStatement

Children of `LabeledStatement`.

LiteralTypeNode

Children of `LiteralTypeNode`.

MappedTypeNode

Children of `MappedTypeNode`.

MetaProperty

Children of `MetaProperty`.

MethodDeclaration

Children of `MethodDeclaration`.

MethodSignatureDeclaration

Children of `MethodSignatureDeclaration`.

MissingDeclaration

Children of `MissingDeclaration`.

ModuleBlock

Children of `ModuleBlock`.

ModuleDeclaration

Children of `ModuleDeclaration`.

NamedExports

Children of `NamedExports`.

NamedImports

Children of `NamedImports`.

NamedTupleMember

Children of `NamedTupleMember`.

NamespaceExport

Children of `NamespaceExport`.

NamespaceExportDeclaration

Children of `NamespaceExportDeclaration`.

NamespaceImport

Children of `NamespaceImport`.

NewExpression

Children of `NewExpression`.

NoSubstitutionTemplateLiteral

Data of `NoSubstitutionTemplateLiteral`, which has no children.

NonNullExpression

Children of `NonNullExpression`.

NumericLiteral

Data of `NumericLiteral`, which has no children.

ObjectLiteralExpression

Children of `ObjectLiteralExpression`.

OptionalTypeNode

Children of `OptionalTypeNode`.

ParameterDeclaration

Children of `ParameterDeclaration`.

ParenthesizedExpression

Children of `ParenthesizedExpression`.

ParenthesizedTypeNode

Children of `ParenthesizedTypeNode`.

PartiallyEmittedExpression

Children of `PartiallyEmittedExpression`.

PostfixUnaryExpression

Children of `PostfixUnaryExpression`.

PrefixUnaryExpression

Children of `PrefixUnaryExpression`.

PrivateIdentifier

Data of `PrivateIdentifier`, which has no children.

PropertyAccessExpression

Children of `PropertyAccessExpression`.

PropertyAssignment

Children of `PropertyAssignment`.

PropertyDeclaration

Children of `PropertyDeclaration`.

PropertySignatureDeclaration

Children of `PropertySignatureDeclaration`.

QualifiedName

Children of `QualifiedName`.

RegularExpressionLiteral

Data of `RegularExpressionLiteral`, which has no children.

RestTypeNode

Children of `RestTypeNode`.

ReturnStatement

Children of `ReturnStatement`.

SatisfiesExpression

Children of `SatisfiesExpression`.

SetAccessorDeclaration

Children of `SetAccessorDeclaration`.

ShorthandPropertyAssignment

Children of `ShorthandPropertyAssignment`.

SourceFile

Children of `SourceFile`.

SpreadAssignment

Children of `SpreadAssignment`.

SpreadElement

Children of `SpreadElement`.

StringLiteral

Data of `StringLiteral`, which has no children.

SwitchStatement

Children of `SwitchStatement`.

SyntaxList

Children of `SyntaxList`.

SyntheticExpression

Children of `SyntheticExpression`.

SyntheticReferenceExpression

Children of `SyntheticReferenceExpression`.

TaggedTemplateExpression

Children of `TaggedTemplateExpression`.

TemplateExpression

Children of `TemplateExpression`.

TemplateHead

Data of `TemplateHead`, which has no children.

TemplateLiteralTypeNode

Children of `TemplateLiteralTypeNode`.

TemplateLiteralTypeSpan

Children of `TemplateLiteralTypeSpan`.

TemplateMiddle

Data of `TemplateMiddle`, which has no children.

TemplateSpan

Children of `TemplateSpan`.

TemplateTail

Data of `TemplateTail`, which has no children.

ThrowStatement

Children of `ThrowStatement`.

TryStatement

Children of `TryStatement`.

TupleTypeNode

Children of `TupleTypeNode`.

TypeAliasDeclaration

Children of `TypeAliasDeclaration`.

TypeAssertion

Children of `TypeAssertion`.

TypeLiteralNode

Children of `TypeLiteralNode`.

TypeOfExpression

Children of `TypeOfExpression`.

TypeOperatorNode

Children of `TypeOperatorNode`.

TypeParameterDeclaration

Children of `TypeParameterDeclaration`.

TypePredicateNode

Children of `TypePredicateNode`.

TypeQueryNode

Children of `TypeQueryNode`.

TypeReferenceNode

Children of `TypeReferenceNode`.

UnionTypeNode

Children of `UnionTypeNode`.

VariableDeclaration

Children of `VariableDeclaration`.

VariableDeclarationList

Children of `VariableDeclarationList`.

VariableStatement

Children of `VariableStatement`.

VoidExpression

Children of `VoidExpression`.

WhileStatement

Children of `WhileStatement`.

WithStatement

Children of `WithStatement`.

YieldExpression

Children of `YieldExpression`.

Type something to start searching.