Logo Xantham

BigIntLiteral Module

Data of `BigIntLiteral`, which has no children.

Functions and values

Function or value Description

BigIntLiteral.text node

Full Usage: BigIntLiteral.text node

Parameters:
Returns: string voption

The `BigIntLiteral`'s text, cooked rather than as spelled in the source.

node : Node<BigIntLiteral>
Returns: string voption

BigIntLiteral.tokenFlags node

Full Usage: BigIntLiteral.tokenFlags node

Parameters:
Returns: TokenFlags voption

The literal's `TokenFlags` - the only way back to how it was spelled.

node : Node<BigIntLiteral>
Returns: TokenFlags voption

Type something to start searching.