Logo Xantham

NumericLiteral Module

Data of `NumericLiteral`, which has no children.

Functions and values

Function or value Description

NumericLiteral.text node

Full Usage: NumericLiteral.text node

Parameters:
Returns: string voption

The `NumericLiteral`'s text, cooked rather than as spelled in the source.

node : Node<NumericLiteral>
Returns: string voption

NumericLiteral.tokenFlags node

Full Usage: NumericLiteral.tokenFlags node

Parameters:
Returns: TokenFlags voption

The literal's `TokenFlags` - the only way back to how it was spelled.

node : Node<NumericLiteral>
Returns: TokenFlags voption

Type something to start searching.