Logo Xantham

RegularExpressionLiteral Module

Data of `RegularExpressionLiteral`, which has no children.

Functions and values

Function or value Description

RegularExpressionLiteral.text node

Full Usage: RegularExpressionLiteral.text node

Parameters:
Returns: string voption

The `RegularExpressionLiteral`'s text, cooked rather than as spelled in the source.

node : Node<RegularExpressionLiteral>
Returns: string voption

RegularExpressionLiteral.tokenFlags node

Full Usage: RegularExpressionLiteral.tokenFlags node

Parameters:
Returns: TokenFlags voption

The literal's `TokenFlags` - the only way back to how it was spelled.

node : Node<RegularExpressionLiteral>
Returns: TokenFlags voption

Type something to start searching.