Logo Xantham

StringLiteral Module

Data of `StringLiteral`, which has no children.

Functions and values

Function or value Description

StringLiteral.text node

Full Usage: StringLiteral.text node

Parameters:
Returns: string voption

The `StringLiteral`'s text, cooked rather than as spelled in the source.

node : Node<StringLiteral>
Returns: string voption

StringLiteral.tokenFlags node

Full Usage: StringLiteral.tokenFlags node

Parameters:
Returns: TokenFlags voption

The literal's `TokenFlags` - the only way back to how it was spelled.

node : Node<StringLiteral>
Returns: TokenFlags voption

Type something to start searching.