Logo Xantham

AsyncSessionExtensions Type

The mirror of `SessionExtensions` over `TscMailbox`: same names, same arguments, each result wrapped in `Async`. Calls that overlap in time are collected into a single round trip.

Static members

Static member Description

AsyncSessionExtensions.emit (this, ?emitOnly)

Full Usage: AsyncSessionExtensions.emit (this, ?emitOnly)

Parameters:
Returns: Async<EmitResponse>
this : Session<TscMailbox>
?emitOnly : int
Returns: Async<EmitResponse>

AsyncSessionExtensions.emitToString (this, ?emitOnly)

Full Usage: AsyncSessionExtensions.emitToString (this, ?emitOnly)

Parameters:
Returns: Async<EmitOutputResponse>
this : Session<TscMailbox>
?emitOnly : int
Returns: Async<EmitOutputResponse>

AsyncSessionExtensions.formatNodeForInsertion (this, file, position, data)

Full Usage: AsyncSessionExtensions.formatNodeForInsertion (this, file, position, data)

Parameters:
Returns: Async<string>
this : Session<TscMailbox>
file : DocumentIdentifier
position : int
data : string
Returns: Async<string>

AsyncSessionExtensions.getAliasSymbolOfType (this, objectId)

Full Usage: AsyncSessionExtensions.getAliasSymbolOfType (this, objectId)

Parameters:
Returns: Async<SymbolResponse voption>
this : Session<TscMailbox>
objectId : int
Returns: Async<SymbolResponse voption>

AsyncSessionExtensions.getAliasTypeArgumentsOfType (this, objectId)

Full Usage: AsyncSessionExtensions.getAliasTypeArgumentsOfType (this, objectId)

Parameters:
Returns: Async<TypeResponse[] voption>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse[] voption>

AsyncSessionExtensions.getAliasedSymbol (this, symbol)

Full Usage: AsyncSessionExtensions.getAliasedSymbol (this, symbol)

Parameters:
Returns: Async<SymbolResponse>
this : Session<TscMailbox>
symbol : int
Returns: Async<SymbolResponse>

AsyncSessionExtensions.getAnyType this

Full Usage: AsyncSessionExtensions.getAnyType this

Parameters:
Returns: Async<TypeResponse>

AsyncSessionExtensions.getApparentPropertiesOfType (this, objectId)

Full Usage: AsyncSessionExtensions.getApparentPropertiesOfType (this, objectId)

Parameters:
Returns: Async<SymbolResponse[]>
this : Session<TscMailbox>
objectId : int
Returns: Async<SymbolResponse[]>

AsyncSessionExtensions.getApparentType (this, objectId)

Full Usage: AsyncSessionExtensions.getApparentType (this, objectId)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>

AsyncSessionExtensions.getBaseConstraintOfType (this, type)

Full Usage: AsyncSessionExtensions.getBaseConstraintOfType (this, type)

Parameters:
Returns: Async<TypeResponse voption>
this : Session<TscMailbox>
type : int
Returns: Async<TypeResponse voption>

AsyncSessionExtensions.getBaseTypeOfLiteralType (this, type)

Full Usage: AsyncSessionExtensions.getBaseTypeOfLiteralType (this, type)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
type : int
Returns: Async<TypeResponse>

AsyncSessionExtensions.getBaseTypeOfType (this, objectId)

Full Usage: AsyncSessionExtensions.getBaseTypeOfType (this, objectId)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>

AsyncSessionExtensions.getBaseTypes (this, type)

Full Usage: AsyncSessionExtensions.getBaseTypes (this, type)

Parameters:
Returns: Async<TypeResponse[] voption>
this : Session<TscMailbox>
type : int
Returns: Async<TypeResponse[] voption>

AsyncSessionExtensions.getBigIntType this

Full Usage: AsyncSessionExtensions.getBigIntType this

Parameters:
Returns: Async<TypeResponse>

AsyncSessionExtensions.getBindDiagnostics (this, ?files)

Full Usage: AsyncSessionExtensions.getBindDiagnostics (this, ?files)

Parameters:
Returns: Async<DiagnosticResponse[] voption>
this : Session<TscMailbox>
?files : DocumentIdentifier[]
Returns: Async<DiagnosticResponse[] voption>

AsyncSessionExtensions.getBooleanType this

Full Usage: AsyncSessionExtensions.getBooleanType this

Parameters:
Returns: Async<TypeResponse>

AsyncSessionExtensions.getCheckTypeOfType (this, objectId)

Full Usage: AsyncSessionExtensions.getCheckTypeOfType (this, objectId)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>

AsyncSessionExtensions.getCompletionsAtPosition (this, file, position, ?triggerCharacter, ?includeSymbol)

Full Usage: AsyncSessionExtensions.getCompletionsAtPosition (this, file, position, ?triggerCharacter, ?includeSymbol)

Parameters:
Returns: Async<CompletionInfoResponse voption>
this : Session<TscMailbox>
file : DocumentIdentifier
position : int
?triggerCharacter : string
?includeSymbol : bool
Returns: Async<CompletionInfoResponse voption>

AsyncSessionExtensions.getConfigFileNames this

Full Usage: AsyncSessionExtensions.getConfigFileNames this

Parameters:
Returns: Async<string[] voption>
this : Session<TscMailbox>
Returns: Async<string[] voption>

AsyncSessionExtensions.getConfigFileParsingDiagnostics this

Full Usage: AsyncSessionExtensions.getConfigFileParsingDiagnostics this

Parameters:
Returns: Async<DiagnosticResponse[] voption>
this : Session<TscMailbox>
Returns: Async<DiagnosticResponse[] voption>

AsyncSessionExtensions.getConfigSourceFile (this, file)

Full Usage: AsyncSessionExtensions.getConfigSourceFile (this, file)

Parameters:
Returns: Async<SourceFile voption>
this : Session<TscMailbox>
file : DocumentIdentifier
Returns: Async<SourceFile voption>

AsyncSessionExtensions.getConstantValue (this, location)

Full Usage: AsyncSessionExtensions.getConstantValue (this, location)

Parameters:
Returns: Async<JsonNode voption>
this : Session<TscMailbox>
location : string
Returns: Async<JsonNode voption>

AsyncSessionExtensions.getConstraintOfType (this, objectId)

Full Usage: AsyncSessionExtensions.getConstraintOfType (this, objectId)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>

AsyncSessionExtensions.getConstraintOfTypeParameter (this, objectId)

Full Usage: AsyncSessionExtensions.getConstraintOfTypeParameter (this, objectId)

Parameters:
Returns: Async<TypeResponse voption>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse voption>

AsyncSessionExtensions.getContextualType (this, location)

Full Usage: AsyncSessionExtensions.getContextualType (this, location)

Parameters:
Returns: Async<TypeResponse voption>
this : Session<TscMailbox>
location : string
Returns: Async<TypeResponse voption>

AsyncSessionExtensions.getDeclarationDiagnostics (this, ?files)

Full Usage: AsyncSessionExtensions.getDeclarationDiagnostics (this, ?files)

Parameters:
Returns: Async<DiagnosticResponse[] voption>
this : Session<TscMailbox>
?files : DocumentIdentifier[]
Returns: Async<DiagnosticResponse[] voption>

AsyncSessionExtensions.getDeclarationEmit (this, ?files)

Full Usage: AsyncSessionExtensions.getDeclarationEmit (this, ?files)

Parameters:
Returns: Async<EmitOutputResponse>

AsyncSessionExtensions.getDeclaredTypeOfSymbol (this, symbol)

Full Usage: AsyncSessionExtensions.getDeclaredTypeOfSymbol (this, symbol)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
symbol : int
Returns: Async<TypeResponse>

AsyncSessionExtensions.getDefaultFromTypeParameter (this, objectId)

Full Usage: AsyncSessionExtensions.getDefaultFromTypeParameter (this, objectId)

Parameters:
Returns: Async<TypeResponse voption>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse voption>

AsyncSessionExtensions.getDefaultProjectForFile (this, file)

Full Usage: AsyncSessionExtensions.getDefaultProjectForFile (this, file)

Parameters:
Returns: Async<ProjectResponse voption>
this : Session<TscMailbox>
file : DocumentIdentifier
Returns: Async<ProjectResponse voption>

AsyncSessionExtensions.getDocumentationComment (this, symbol)

Full Usage: AsyncSessionExtensions.getDocumentationComment (this, symbol)

Parameters:
Returns: Async<string>
this : Session<TscMailbox>
symbol : int
Returns: Async<string>

AsyncSessionExtensions.getESSymbolType this

Full Usage: AsyncSessionExtensions.getESSymbolType this

Parameters:
Returns: Async<TypeResponse>

AsyncSessionExtensions.getExportSpecifierLocalTargetSymbol (this, location)

Full Usage: AsyncSessionExtensions.getExportSpecifierLocalTargetSymbol (this, location)

Parameters:
Returns: Async<SymbolResponse voption>
this : Session<TscMailbox>
location : string
Returns: Async<SymbolResponse voption>

AsyncSessionExtensions.getExportSymbolOfSymbol (this, objectId)

Full Usage: AsyncSessionExtensions.getExportSymbolOfSymbol (this, objectId)

Parameters:
Returns: Async<SymbolResponse voption>
this : Session<TscMailbox>
objectId : int
Returns: Async<SymbolResponse voption>

AsyncSessionExtensions.getExportsOfModule (this, symbol)

Full Usage: AsyncSessionExtensions.getExportsOfModule (this, symbol)

Parameters:
Returns: Async<SymbolResponse[] voption>
this : Session<TscMailbox>
symbol : int
Returns: Async<SymbolResponse[] voption>

AsyncSessionExtensions.getExportsOfSymbol (this, objectId)

Full Usage: AsyncSessionExtensions.getExportsOfSymbol (this, objectId)

Parameters:
Returns: Async<SymbolResponse[] voption>
this : Session<TscMailbox>
objectId : int
Returns: Async<SymbolResponse[] voption>

AsyncSessionExtensions.getExtendsTypeOfType (this, objectId)

Full Usage: AsyncSessionExtensions.getExtendsTypeOfType (this, objectId)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>

AsyncSessionExtensions.getFalseTypeOfConditionalType (this, objectId)

Full Usage: AsyncSessionExtensions.getFalseTypeOfConditionalType (this, objectId)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>

AsyncSessionExtensions.getFreshTypeOfType (this, objectId)

Full Usage: AsyncSessionExtensions.getFreshTypeOfType (this, objectId)

Parameters:
Returns: Async<TypeResponse voption>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse voption>

AsyncSessionExtensions.getFullyQualifiedName (this, symbol)

Full Usage: AsyncSessionExtensions.getFullyQualifiedName (this, symbol)

Parameters:
Returns: Async<string>
this : Session<TscMailbox>
symbol : int
Returns: Async<string>

AsyncSessionExtensions.getGlobalDiagnostics this

Full Usage: AsyncSessionExtensions.getGlobalDiagnostics this

Parameters:
Returns: Async<DiagnosticResponse[] voption>
this : Session<TscMailbox>
Returns: Async<DiagnosticResponse[] voption>

AsyncSessionExtensions.getImmediateAliasedSymbol (this, symbol)

Full Usage: AsyncSessionExtensions.getImmediateAliasedSymbol (this, symbol)

Parameters:
Returns: Async<SymbolResponse voption>
this : Session<TscMailbox>
symbol : int
Returns: Async<SymbolResponse voption>

AsyncSessionExtensions.getImportAdderEdits (this, file, ?actions)

Full Usage: AsyncSessionExtensions.getImportAdderEdits (this, file, ?actions)

Parameters:
Returns: Async<TextEdit[]>
this : Session<TscMailbox>
file : DocumentIdentifier
?actions : ImportAdderAction[]
Returns: Async<TextEdit[]>

AsyncSessionExtensions.getIndexInfosOfType (this, type)

Full Usage: AsyncSessionExtensions.getIndexInfosOfType (this, type)

Parameters:
Returns: Async<IndexInfoResponse[] voption>
this : Session<TscMailbox>
type : int
Returns: Async<IndexInfoResponse[] voption>

AsyncSessionExtensions.getIndexTypeOfType (this, objectId)

Full Usage: AsyncSessionExtensions.getIndexTypeOfType (this, objectId)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>

AsyncSessionExtensions.getJavaScriptEmit (this, ?files)

Full Usage: AsyncSessionExtensions.getJavaScriptEmit (this, ?files)

Parameters:
Returns: Async<EmitOutputResponse>

AsyncSessionExtensions.getJsDocTags (this, symbol)

Full Usage: AsyncSessionExtensions.getJsDocTags (this, symbol)

Parameters:
Returns: Async<JSDocTagInfo[] voption>
this : Session<TscMailbox>
symbol : int
Returns: Async<JSDocTagInfo[] voption>

AsyncSessionExtensions.getLocalTypeParametersOfType (this, objectId)

Full Usage: AsyncSessionExtensions.getLocalTypeParametersOfType (this, objectId)

Parameters:
Returns: Async<TypeResponse[] voption>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse[] voption>

AsyncSessionExtensions.getMemberInModuleExports (this, symbol, name)

Full Usage: AsyncSessionExtensions.getMemberInModuleExports (this, symbol, name)

Parameters:
Returns: Async<SymbolResponse voption>
this : Session<TscMailbox>
symbol : int
name : string
Returns: Async<SymbolResponse voption>

AsyncSessionExtensions.getMembersOfSymbol (this, objectId)

Full Usage: AsyncSessionExtensions.getMembersOfSymbol (this, objectId)

Parameters:
Returns: Async<SymbolResponse[] voption>
this : Session<TscMailbox>
objectId : int
Returns: Async<SymbolResponse[] voption>

AsyncSessionExtensions.getNeverType this

Full Usage: AsyncSessionExtensions.getNeverType this

Parameters:
Returns: Async<TypeResponse>

AsyncSessionExtensions.getNonMissingTypeOfSymbol (this, symbol)

Full Usage: AsyncSessionExtensions.getNonMissingTypeOfSymbol (this, symbol)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
symbol : int
Returns: Async<TypeResponse>

AsyncSessionExtensions.getNonNullableType (this, objectId)

Full Usage: AsyncSessionExtensions.getNonNullableType (this, objectId)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>

AsyncSessionExtensions.getNonPrimitiveType this

Full Usage: AsyncSessionExtensions.getNonPrimitiveType this

Parameters:
Returns: Async<TypeResponse>

AsyncSessionExtensions.getNullType this

Full Usage: AsyncSessionExtensions.getNullType this

Parameters:
Returns: Async<TypeResponse>

AsyncSessionExtensions.getNumberType this

Full Usage: AsyncSessionExtensions.getNumberType this

Parameters:
Returns: Async<TypeResponse>

AsyncSessionExtensions.getObjectTypeOfType (this, objectId)

Full Usage: AsyncSessionExtensions.getObjectTypeOfType (this, objectId)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>

AsyncSessionExtensions.getOuterTypeParametersOfType (this, objectId)

Full Usage: AsyncSessionExtensions.getOuterTypeParametersOfType (this, objectId)

Parameters:
Returns: Async<TypeResponse[] voption>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse[] voption>

AsyncSessionExtensions.getParameterType (this, signature, index)

Full Usage: AsyncSessionExtensions.getParameterType (this, signature, index)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
signature : int
index : int
Returns: Async<TypeResponse>

AsyncSessionExtensions.getParametersOfSignature (this, objectId)

Full Usage: AsyncSessionExtensions.getParametersOfSignature (this, objectId)

Parameters:
Returns: Async<SymbolResponse[] voption>
this : Session<TscMailbox>
objectId : int
Returns: Async<SymbolResponse[] voption>

AsyncSessionExtensions.getParentOfSymbol (this, objectId)

Full Usage: AsyncSessionExtensions.getParentOfSymbol (this, objectId)

Parameters:
Returns: Async<SymbolResponse voption>
this : Session<TscMailbox>
objectId : int
Returns: Async<SymbolResponse voption>

AsyncSessionExtensions.getProgramDiagnostics this

Full Usage: AsyncSessionExtensions.getProgramDiagnostics this

Parameters:
Returns: Async<DiagnosticResponse[] voption>
this : Session<TscMailbox>
Returns: Async<DiagnosticResponse[] voption>

AsyncSessionExtensions.getPropertiesOfType (this, type)

Full Usage: AsyncSessionExtensions.getPropertiesOfType (this, type)

Parameters:
Returns: Async<SymbolResponse[] voption>
this : Session<TscMailbox>
type : int
Returns: Async<SymbolResponse[] voption>

AsyncSessionExtensions.getPropertyOfType (this, type, name)

Full Usage: AsyncSessionExtensions.getPropertyOfType (this, type, name)

Parameters:
Returns: Async<SymbolResponse voption>
this : Session<TscMailbox>
type : int
name : string
Returns: Async<SymbolResponse voption>

AsyncSessionExtensions.getReducedType (this, objectId)

Full Usage: AsyncSessionExtensions.getReducedType (this, objectId)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>

AsyncSessionExtensions.getReferencedSymbolsForNode (this, node, position)

Full Usage: AsyncSessionExtensions.getReferencedSymbolsForNode (this, node, position)

Parameters:
Returns: Async<ReferencedSymbolEntry[] voption>
this : Session<TscMailbox>
node : string
position : int
Returns: Async<ReferencedSymbolEntry[] voption>

AsyncSessionExtensions.getReferencesToSymbolInFile (this, file, symbol)

Full Usage: AsyncSessionExtensions.getReferencesToSymbolInFile (this, file, symbol)

Parameters:
Returns: Async<string[]>
this : Session<TscMailbox>
file : DocumentIdentifier
symbol : int
Returns: Async<string[]>

AsyncSessionExtensions.getRegularTypeOfType (this, objectId)

Full Usage: AsyncSessionExtensions.getRegularTypeOfType (this, objectId)

Parameters:
Returns: Async<TypeResponse voption>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse voption>

AsyncSessionExtensions.getResolvedSignature (this, location)

Full Usage: AsyncSessionExtensions.getResolvedSignature (this, location)

Parameters:
Returns: Async<SignatureResponse>
this : Session<TscMailbox>
location : string
Returns: Async<SignatureResponse>

AsyncSessionExtensions.getRestTypeOfSignature (this, signature)

Full Usage: AsyncSessionExtensions.getRestTypeOfSignature (this, signature)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
signature : int
Returns: Async<TypeResponse>

AsyncSessionExtensions.getReturnTypeOfSignature (this, objectId)

Full Usage: AsyncSessionExtensions.getReturnTypeOfSignature (this, objectId)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>

AsyncSessionExtensions.getSemanticDiagnostics (this, ?files)

Full Usage: AsyncSessionExtensions.getSemanticDiagnostics (this, ?files)

Parameters:
Returns: Async<DiagnosticResponse[] voption>
this : Session<TscMailbox>
?files : DocumentIdentifier[]
Returns: Async<DiagnosticResponse[] voption>

AsyncSessionExtensions.getShorthandAssignmentValueSymbol (this, location)

Full Usage: AsyncSessionExtensions.getShorthandAssignmentValueSymbol (this, location)

Parameters:
Returns: Async<SymbolResponse voption>
this : Session<TscMailbox>
location : string
Returns: Async<SymbolResponse voption>

AsyncSessionExtensions.getSignatureFromDeclaration (this, location)

Full Usage: AsyncSessionExtensions.getSignatureFromDeclaration (this, location)

Parameters:
Returns: Async<SignatureResponse>
this : Session<TscMailbox>
location : string
Returns: Async<SignatureResponse>

AsyncSessionExtensions.getSignatureUsages (this, signatureDecl)

Full Usage: AsyncSessionExtensions.getSignatureUsages (this, signatureDecl)

Parameters:
Returns: Async<SignatureUsageResponse[] voption>
this : Session<TscMailbox>
signatureDecl : string
Returns: Async<SignatureUsageResponse[] voption>

AsyncSessionExtensions.getSignaturesOfType (this, type, kind)

Full Usage: AsyncSessionExtensions.getSignaturesOfType (this, type, kind)

Parameters:
Returns: Async<SignatureResponse[]>
this : Session<TscMailbox>
type : int
kind : SignatureKind
Returns: Async<SignatureResponse[]>

AsyncSessionExtensions.getSourceFile (this, file)

Full Usage: AsyncSessionExtensions.getSourceFile (this, file)

Parameters:
Returns: Async<SourceFile voption>
this : Session<TscMailbox>
file : DocumentIdentifier
Returns: Async<SourceFile voption>

AsyncSessionExtensions.getSourceFileMetadata (this, file)

Full Usage: AsyncSessionExtensions.getSourceFileMetadata (this, file)

Parameters:
Returns: Async<SourceFileMetadata voption>

AsyncSessionExtensions.getSourceFileNames this

Full Usage: AsyncSessionExtensions.getSourceFileNames this

Parameters:
Returns: Async<string[]>
this : Session<TscMailbox>
Returns: Async<string[]>

AsyncSessionExtensions.getStringType this

Full Usage: AsyncSessionExtensions.getStringType this

Parameters:
Returns: Async<TypeResponse>

AsyncSessionExtensions.getSuggestionDiagnostics (this, ?files)

Full Usage: AsyncSessionExtensions.getSuggestionDiagnostics (this, ?files)

Parameters:
Returns: Async<DiagnosticResponse[] voption>
this : Session<TscMailbox>
?files : DocumentIdentifier[]
Returns: Async<DiagnosticResponse[] voption>

AsyncSessionExtensions.getSymbolAtLocation (this, location)

Full Usage: AsyncSessionExtensions.getSymbolAtLocation (this, location)

Parameters:
Returns: Async<SymbolResponse voption>
this : Session<TscMailbox>
location : string
Returns: Async<SymbolResponse voption>

AsyncSessionExtensions.getSymbolAtPosition (this, file, position)

Full Usage: AsyncSessionExtensions.getSymbolAtPosition (this, file, position)

Parameters:
Returns: Async<SymbolResponse voption>
this : Session<TscMailbox>
file : DocumentIdentifier
position : int
Returns: Async<SymbolResponse voption>

AsyncSessionExtensions.getSymbolOfSourceFile (this, file)

Full Usage: AsyncSessionExtensions.getSymbolOfSourceFile (this, file)

Parameters:
Returns: Async<SymbolResponse voption>
this : Session<TscMailbox>
file : DocumentIdentifier
Returns: Async<SymbolResponse voption>

AsyncSessionExtensions.getSymbolOfType (this, objectId)

Full Usage: AsyncSessionExtensions.getSymbolOfType (this, objectId)

Parameters:
Returns: Async<SymbolResponse voption>
this : Session<TscMailbox>
objectId : int
Returns: Async<SymbolResponse voption>

AsyncSessionExtensions.getSymbolsAtLocations (this, ?locations)

Full Usage: AsyncSessionExtensions.getSymbolsAtLocations (this, ?locations)

Parameters:
Returns: Async<SymbolResponse[]>
this : Session<TscMailbox>
?locations : string[]
Returns: Async<SymbolResponse[]>

AsyncSessionExtensions.getSymbolsAtPositions (this, file, ?positions)

Full Usage: AsyncSessionExtensions.getSymbolsAtPositions (this, file, ?positions)

Parameters:
Returns: Async<SymbolResponse[]>
this : Session<TscMailbox>
file : DocumentIdentifier
?positions : int[]
Returns: Async<SymbolResponse[]>

AsyncSessionExtensions.getSymbolsInScope (this, meaning, ?location, ?file, ?position)

Full Usage: AsyncSessionExtensions.getSymbolsInScope (this, meaning, ?location, ?file, ?position)

Parameters:
Returns: Async<SymbolResponse[]>
this : Session<TscMailbox>
meaning : SymbolFlags
?location : string
?file : DocumentIdentifier
?position : int
Returns: Async<SymbolResponse[]>

AsyncSessionExtensions.getSymbolsOfSourceFiles (this, ?files)

Full Usage: AsyncSessionExtensions.getSymbolsOfSourceFiles (this, ?files)

Parameters:
Returns: Async<SymbolResponse[]>

AsyncSessionExtensions.getSyntacticDiagnostics (this, ?files)

Full Usage: AsyncSessionExtensions.getSyntacticDiagnostics (this, ?files)

Parameters:
Returns: Async<DiagnosticResponse[] voption>
this : Session<TscMailbox>
?files : DocumentIdentifier[]
Returns: Async<DiagnosticResponse[] voption>

AsyncSessionExtensions.getTargetOfSignature (this, objectId)

Full Usage: AsyncSessionExtensions.getTargetOfSignature (this, objectId)

Parameters:
Returns: Async<SignatureResponse voption>
this : Session<TscMailbox>
objectId : int
Returns: Async<SignatureResponse voption>

AsyncSessionExtensions.getTargetOfType (this, objectId)

Full Usage: AsyncSessionExtensions.getTargetOfType (this, objectId)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>

AsyncSessionExtensions.getTargetSymbol (this, symbol)

Full Usage: AsyncSessionExtensions.getTargetSymbol (this, symbol)

Parameters:
Returns: Async<SymbolResponse>
this : Session<TscMailbox>
symbol : int
Returns: Async<SymbolResponse>

AsyncSessionExtensions.getThisParameterOfSignature (this, objectId)

Full Usage: AsyncSessionExtensions.getThisParameterOfSignature (this, objectId)

Parameters:
Returns: Async<SymbolResponse voption>
this : Session<TscMailbox>
objectId : int
Returns: Async<SymbolResponse voption>

AsyncSessionExtensions.getTrueTypeOfConditionalType (this, objectId)

Full Usage: AsyncSessionExtensions.getTrueTypeOfConditionalType (this, objectId)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>

AsyncSessionExtensions.getTypeArguments (this, type)

Full Usage: AsyncSessionExtensions.getTypeArguments (this, type)

Parameters:
Returns: Async<TypeResponse[] voption>
this : Session<TscMailbox>
type : int
Returns: Async<TypeResponse[] voption>

AsyncSessionExtensions.getTypeAtLocation (this, location)

Full Usage: AsyncSessionExtensions.getTypeAtLocation (this, location)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
location : string
Returns: Async<TypeResponse>

AsyncSessionExtensions.getTypeAtLocations (this, ?locations)

Full Usage: AsyncSessionExtensions.getTypeAtLocations (this, ?locations)

Parameters:
Returns: Async<TypeResponse[]>
this : Session<TscMailbox>
?locations : string[]
Returns: Async<TypeResponse[]>

AsyncSessionExtensions.getTypeAtPosition (this, file, position)

Full Usage: AsyncSessionExtensions.getTypeAtPosition (this, file, position)

Parameters:
Returns: Async<TypeResponse voption>
this : Session<TscMailbox>
file : DocumentIdentifier
position : int
Returns: Async<TypeResponse voption>

AsyncSessionExtensions.getTypeFromTypeNode (this, location)

Full Usage: AsyncSessionExtensions.getTypeFromTypeNode (this, location)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
location : string
Returns: Async<TypeResponse>

AsyncSessionExtensions.getTypeOfSymbol (this, symbol)

Full Usage: AsyncSessionExtensions.getTypeOfSymbol (this, symbol)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
symbol : int
Returns: Async<TypeResponse>

AsyncSessionExtensions.getTypeOfSymbolAtLocation (this, symbol, location)

Full Usage: AsyncSessionExtensions.getTypeOfSymbolAtLocation (this, symbol, location)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
symbol : int
location : string
Returns: Async<TypeResponse>

AsyncSessionExtensions.getTypeParameterAtPosition (this, signature, index)

Full Usage: AsyncSessionExtensions.getTypeParameterAtPosition (this, signature, index)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
signature : int
index : int
Returns: Async<TypeResponse>

AsyncSessionExtensions.getTypeParametersOfSignature (this, objectId)

Full Usage: AsyncSessionExtensions.getTypeParametersOfSignature (this, objectId)

Parameters:
Returns: Async<TypeResponse[] voption>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse[] voption>

AsyncSessionExtensions.getTypeParametersOfType (this, objectId)

Full Usage: AsyncSessionExtensions.getTypeParametersOfType (this, objectId)

Parameters:
Returns: Async<TypeResponse[] voption>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse[] voption>

AsyncSessionExtensions.getTypePredicateOfSignature (this, signature)

Full Usage: AsyncSessionExtensions.getTypePredicateOfSignature (this, signature)

Parameters:
Returns: Async<TypePredicateResponse voption>
this : Session<TscMailbox>
signature : int
Returns: Async<TypePredicateResponse voption>

AsyncSessionExtensions.getTypesAtPositions (this, file, ?positions)

Full Usage: AsyncSessionExtensions.getTypesAtPositions (this, file, ?positions)

Parameters:
Returns: Async<TypeResponse[]>
this : Session<TscMailbox>
file : DocumentIdentifier
?positions : int[]
Returns: Async<TypeResponse[]>

AsyncSessionExtensions.getTypesOfSymbols (this, ?symbols)

Full Usage: AsyncSessionExtensions.getTypesOfSymbols (this, ?symbols)

Parameters:
Returns: Async<TypeResponse[]>
this : Session<TscMailbox>
?symbols : int[]
Returns: Async<TypeResponse[]>

AsyncSessionExtensions.getTypesOfType (this, objectId)

Full Usage: AsyncSessionExtensions.getTypesOfType (this, objectId)

Parameters:
Returns: Async<TypeResponse[] voption>
this : Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse[] voption>

AsyncSessionExtensions.getUndefinedType this

Full Usage: AsyncSessionExtensions.getUndefinedType this

Parameters:
Returns: Async<TypeResponse>

AsyncSessionExtensions.getUnknownType this

Full Usage: AsyncSessionExtensions.getUnknownType this

Parameters:
Returns: Async<TypeResponse>

AsyncSessionExtensions.getVoidType this

Full Usage: AsyncSessionExtensions.getVoidType this

Parameters:
Returns: Async<TypeResponse>

AsyncSessionExtensions.getWellKnownSignatures this

Full Usage: AsyncSessionExtensions.getWellKnownSignatures this

Parameters:
Returns: Async<WellKnownSignaturesResponse>

AsyncSessionExtensions.getWellKnownSymbols this

Full Usage: AsyncSessionExtensions.getWellKnownSymbols this

Parameters:
Returns: Async<WellKnownSymbolsResponse>

AsyncSessionExtensions.getWidenedType (this, type)

Full Usage: AsyncSessionExtensions.getWidenedType (this, type)

Parameters:
Returns: Async<TypeResponse>
this : Session<TscMailbox>
type : int
Returns: Async<TypeResponse>

AsyncSessionExtensions.isArrayLikeType (this, type)

Full Usage: AsyncSessionExtensions.isArrayLikeType (this, type)

Parameters:
Returns: Async<bool>
this : Session<TscMailbox>
type : int
Returns: Async<bool>

AsyncSessionExtensions.isArrayType (this, type)

Full Usage: AsyncSessionExtensions.isArrayType (this, type)

Parameters:
Returns: Async<bool>
this : Session<TscMailbox>
type : int
Returns: Async<bool>

AsyncSessionExtensions.isContextSensitive (this, location)

Full Usage: AsyncSessionExtensions.isContextSensitive (this, location)

Parameters:
Returns: Async<bool>
this : Session<TscMailbox>
location : string
Returns: Async<bool>

AsyncSessionExtensions.isReadonlySymbol (this, symbol)

Full Usage: AsyncSessionExtensions.isReadonlySymbol (this, symbol)

Parameters:
Returns: Async<bool>
this : Session<TscMailbox>
symbol : int
Returns: Async<bool>

AsyncSessionExtensions.isTypeAssignableTo (this, source, target)

Full Usage: AsyncSessionExtensions.isTypeAssignableTo (this, source, target)

Parameters:
Returns: Async<bool>
this : Session<TscMailbox>
source : int
target : int
Returns: Async<bool>

AsyncSessionExtensions.release this

Full Usage: AsyncSessionExtensions.release this

Parameters:
Returns: Async<unit>
this : Session<TscMailbox>
Returns: Async<unit>

AsyncSessionExtensions.resolveName (this, name, meaning, ?location, ?file, ?position, ?excludeGlobals)

Full Usage: AsyncSessionExtensions.resolveName (this, name, meaning, ?location, ?file, ?position, ?excludeGlobals)

Parameters:
Returns: Async<SymbolResponse voption>
this : Session<TscMailbox>
name : string
meaning : SymbolFlags
?location : string
?file : DocumentIdentifier
?position : int
?excludeGlobals : bool
Returns: Async<SymbolResponse voption>

AsyncSessionExtensions.signatureToSignatureDeclaration (this, signature, kind, ?location, ?flags)

Full Usage: AsyncSessionExtensions.signatureToSignatureDeclaration (this, signature, kind, ?location, ?flags)

Parameters:
Returns: Async<SourceFile voption>
this : Session<TscMailbox>
signature : int
kind : SyntaxKind
?location : string
?flags : NodeBuilderFlags
Returns: Async<SourceFile voption>

AsyncSessionExtensions.typeToString (this, type, ?location, ?flags)

Full Usage: AsyncSessionExtensions.typeToString (this, type, ?location, ?flags)

Parameters:
Returns: Async<JsonNode voption>
this : Session<TscMailbox>
type : int
?location : string
?flags : int
Returns: Async<JsonNode voption>

AsyncSessionExtensions.typeToTypeNode (this, type, ?location, ?flags)

Full Usage: AsyncSessionExtensions.typeToTypeNode (this, type, ?location, ?flags)

Parameters:
Returns: Async<SourceFile voption>
this : Session<TscMailbox>
type : int
?location : string
?flags : int
Returns: Async<SourceFile voption>

AsyncSessionExtensions.updateTemporarySnapshot (this, file, newText)

Full Usage: AsyncSessionExtensions.updateTemporarySnapshot (this, file, newText)

Parameters:
Returns: Async<UpdateSnapshotResponse>
this : Session<TscMailbox>
file : DocumentIdentifier
newText : string
Returns: Async<UpdateSnapshotResponse>

Type something to start searching.