Logo Xantham

ProjectReference Type

Path is a normalized path on disk.

Record fields

Record Field Description

Circular

Full Usage: Circular

Field type: bool

Circular indicates that this reference is intended to form a circularity.

Field type: bool

OriginalPath

Full Usage: OriginalPath

Field type: string

OriginalPath is the path as it was originally written.

Field type: string

Path

Full Usage: Path

Field type: string

Path is a normalized path on disk.

Field type: string

Type something to start searching.