Logo Xantham

SymbolResponse Type

Project is the project in which the symbol was first observed. It is the default project for follow-up lookups whose results can vary by project.

Record fields

Record Field Description

CheckFlags

Full Usage: CheckFlags

Field type: CheckFlags
Field type: CheckFlags

Declarations

Full Usage: Declarations

Field type: string[] voption
Field type: string[] voption

ExportSymbol

Full Usage: ExportSymbol

Field type: int voption
Field type: int voption

Flags

Full Usage: Flags

Field type: SymbolFlags
Field type: SymbolFlags

Id

Full Usage: Id

Field type: int
Field type: int

Name

Full Usage: Name

Field type: string
Field type: string

Parent

Full Usage: Parent

Field type: int voption
Field type: int voption

Project

Full Usage: Project

Field type: string

Project is the project in which the symbol was first observed. It is the default project for follow-up lookups whose results can vary by project.

Field type: string

ValueDeclaration

Full Usage: ValueDeclaration

Field type: string voption
Field type: string voption

Type something to start searching.