Logo Xantham

TypeResponse Type

Value is literal type data. BigInt literals are encoded as signed decimal strings because JSON cannot represent bigint; absent values are null.

Record fields

Record Field Description

AliasSymbol

Full Usage: AliasSymbol

Field type: int voption
Field type: int voption

AliasTypeArguments

Full Usage: AliasTypeArguments

Field type: int[] voption

TypeAlias data

Field type: int[] voption

BaseType

Full Usage: BaseType

Field type: int voption

SubstitutionType data

Field type: int voption

CheckType

Full Usage: CheckType

Field type: int voption

ConditionalType data

Field type: int voption

ElementFlags

Full Usage: ElementFlags

Field type: ElementFlags[] voption

TupleType data

Field type: ElementFlags[] voption

ExtendsType

Full Usage: ExtendsType

Field type: int voption
Field type: int voption

FixedLength

Full Usage: FixedLength

Field type: int voption
Field type: int voption

Flags

Full Usage: Flags

Field type: TypeFlags
Field type: TypeFlags

FreshType

Full Usage: FreshType

Field type: int voption

FreshableType data (LiteralType and computed enum types)

Field type: int voption

Id

Full Usage: Id

Field type: int
Field type: int

IndexType

Full Usage: IndexType

Field type: int voption
Field type: int voption

IntrinsicName

Full Usage: IntrinsicName

Field type: string voption

IntrinsicType data

Field type: string voption

IsThisType

Full Usage: IsThisType

Field type: bool voption

TypeParameter data

Field type: bool voption

IsTupleType

Full Usage: IsTupleType

Field type: bool voption
Field type: bool voption

LabeledElementDeclarations

Full Usage: LabeledElementDeclarations

Field type: string[] voption
Field type: string[] voption

LocalTypeParameters

Full Usage: LocalTypeParameters

Field type: int[] voption
Field type: int[] voption

ObjectFlags

Full Usage: ObjectFlags

Field type: ObjectFlags voption
Field type: ObjectFlags voption

ObjectType

Full Usage: ObjectType

Field type: int voption

IndexedAccessType data

Field type: int voption

OuterTypeParameters

Full Usage: OuterTypeParameters

Field type: int[] voption
Field type: int[] voption

Readonly

Full Usage: Readonly

Field type: bool voption
Field type: bool voption

RegularType

Full Usage: RegularType

Field type: int voption
Field type: int voption

SubstConstraint

Full Usage: SubstConstraint

Field type: int voption
Field type: int voption

Symbol

Full Usage: Symbol

Field type: int voption

Symbol associated with structured types

Field type: int voption

Target

Full Usage: Target

Field type: int voption

ObjectType / TypeReference / StringMappingType / IndexType target

Field type: int voption

Texts

Full Usage: Texts

Field type: string[] voption

TemplateLiteralType text segments

Field type: string[] voption

TypeParameters

Full Usage: TypeParameters

Field type: int[] voption

InterfaceType type parameters

Field type: int[] voption

Value

Full Usage: Value

Field type: JsonNode

Value is literal type data. BigInt literals are encoded as signed decimal strings because JSON cannot represent bigint; absent values are null.

Field type: JsonNode

Type something to start searching.