Logo Xantham

UpdateSnapshotResponse Type

UpdateSnapshotResponse is returned by updateSnapshot.

Record fields

Record Field Description

Changes

Full Usage: Changes

Field type: SnapshotChanges voption

Changes describes source file differences from the previous snapshot. Nil for the first snapshot in a session.

Field type: SnapshotChanges voption

Projects

Full Usage: Projects

Field type: ProjectResponse[]

Projects is the list of projects in the snapshot.

Field type: ProjectResponse[]

Snapshot

Full Usage: Snapshot

Field type: int

Snapshot is the handle for the newly created snapshot.

Field type: int

Type something to start searching.