Logo Xantham

UpdateTemporarySnapshotParams Type

UpdateTemporarySnapshotParams are the parameters for creating a temporary snapshot that overrides a single file's content.

Record fields

Record Field Description

File

Full Usage: File

Field type: DocumentIdentifier

File identifies the file whose content is temporarily overridden.

Field type: DocumentIdentifier

NewText

Full Usage: NewText

Field type: string

NewText is the temporary content for the file.

Field type: string

Snapshot

Full Usage: Snapshot

Field type: int

Snapshot is the current client snapshot on which to layer the temporary update.

Field type: int

Type something to start searching.