Xantham.Decoder Namespace
Contents
Decoded Result
| Type | Description |
|
Intermediate result produced by the compression pass, holding the compressed type and export maps along with the protected top-level export set. |
|
|
Final shape returned by |
|
|
Map from a source module path (string) to the set of |
|
|
Map from a |
|
|
Set of |
|
|
Map from a |
Names and Casing
| Type/Module | Description |
|
This provides unsafe means of removing/adding measures to a |
|
|
A |
|
|
|
|
|
Utility type for working with names or manipulating the names of types and members while preserving the original source. |
|
|
Provide static typing over the casing of a name |
Other namespace members
| Modules | Description |
|
Lazy resolved type graph for use in generators. |
|
|
Discriminated unions tagging a |
|
|
|
|
|
|