Settings Type
Settings for the Decoder.
Record fields
| Record Field |
Description
|
Full Usage:
Compress
Field type: bool
|
Whether to compress the output TypeMap before passing to consumers.
Defaults to
|
Full Usage:
InputFile
Field type: string
|
The path to the
|
Full Usage:
PerformHealthCheck
Field type: bool
|
Whether to perform a health check on the decoded data and determine
if there are any missing or dangling TypeKeys. Defaults to
|
Full Usage:
Sanitize
Field type: bool
|
Whether to sanitize the typemap by replacing cyclical keys with obj.
Defaults to
|
Static members
| Static member |
Description
|
Full Usage:
Settings.Create(inputFile, ?performHealthCheck, ?compress, ?sanitize)
Parameters:
string
?performHealthCheck : bool
?compress : bool
?sanitize : bool
Returns: Settings
|
|