Name Type
Utility type for working with names or manipulating the names of types and members while preserving the original source.
Union cases
| Union case |
Description
|
Full Usage:
Modified(original, modified)
Parameters:
string
modified : string
|
|
Full Usage:
Source original
Parameters:
string
|
|
Instance members
| Instance member |
Description
|
Full Usage:
this.IsModified
Returns: bool
|
|
Full Usage:
this.IsSource
Returns: bool
|
|
Full Usage:
this.ValueOrModified
Returns: string
|
The modified string if the name has been modified; otherwise the original source string.
|
Full Usage:
this.ValueOrSource
Returns: string
|
The original source string regardless of whether the name has been modified.
|
Static members
| Static member |
Description
|
Full Usage:
Name.Create(original, modified)
Parameters:
string
modified : string
Returns: Name
|
Create a
|
|
Create an unmodified
|
Full Usage:
Name.CreateModified(original, modified)
Parameters:
string
modified : string
Returns: Name
|
Create a
|