Name Module
Nested modules
| Modules | Description |
|
Provides means for working with Camel case measure annotated names directly. |
|
|
Provides some equivalency functions for working with Names that have measures. |
|
|
Provides means for working with Module measure annotated names directly. |
|
|
|
|
|
Provides means for working with Pascal case measure annotated names directly. |
|
|
Provides means for working with Typar measure annotated names directly. |
Functions and values
| Function or value |
Description
|
|
|
|
|
|
Creates a Name from a string. Will automatically normalize the name with backticks if required.. Use the static member Create if you don't want automatic normalization.
|
Full Usage:
createModified original modified
Parameters:
string
modified : string
Returns: Name
Modifiers: inline |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Retrieves the modified value for a name if it exists; otherwise returns the original source value.
|
|