proptypelock<'T> Type
Used to represent a type can be any of the types of properties for the given generic. Create a proptypekey with lambdas accessing each of the properties to create a key which statically resolves the actual types of the underlying value.
Instance members
| Instance member |
Description
|
Full Usage:
this[value]
Parameters:
proptypekey<'T, 'ReturnValue>
Returns: 'ReturnValue
Modifiers: inline |
|