Logo Xantham

Xantham.Generator Namespace

Type/Module Description

AnchorScopeStore

AttributeModifierSRTPType<'WidgetModifier, 'WidgetType>

Attributes

AttributesBuilder (Module)

AttributesBuilder (Type)

AttributesBuilderBase

AttributesModifierBuilder<'WidgetModifier, 'WidgetType>

Customisation

DictionaryImpl<'Key, 'Value>

Wrapper that chooses the type of dictionary (concurrent/normal) depending on the presence of the CONCURRENT_DICT constant on compilation

EncoderInvariantViolation

Exprs

GeneratorContext (Module)

GeneratorContext (Type)

InterceptorIgnorePathRender

InterceptorPaths

Interceptors

NamePath

PreludeGetTypeRefFunc

PreludeScopeStore

UnionBuilder (Module)

UnionBuilder (Type)

A builder for WidgetBuilder<Type>s that represent erased unions in Fable. It tracks the lengths of the unions it builds to ensure that we have all erased unions defined in the base set, otherwise we can generate our own.

Utils

WidgetTypes

Type something to start searching.