ExportTypeIds Type
The type ids an export resolves to. A symbol can be both a type and a value (a class), so the two are separate fields rather than one.
The type ids an export resolves to. A symbol can be both a type and a value (a class), so the two are separate fields rather than one.