TypedNameRender Module
Functions and values
| Function or value |
Description
|
Full Usage:
renderAbstract ctx typedName
Parameters:
GeneratorContext
typedName : TypedNameRender
Returns: WidgetBuilder<MemberDefn>
|
|
Full Usage:
renderAbstractImpl withOption ctx typedName
Parameters:
bool
ctx : GeneratorContext
typedName : TypedNameRender
Returns: WidgetBuilder<MemberDefn>
|
|
Full Usage:
renderAbstractNoOption ctx typedName
Parameters:
GeneratorContext
typedName : TypedNameRender
Returns: WidgetBuilder<MemberDefn>
|
|
Full Usage:
renderAsNamedType ctx typedName
Parameters:
GeneratorContext
-
typedName : TypedNameRender
-
Returns: WidgetBuilder<Type>
|
Render a typed name render as a type signature, with the optionality being rendered on the type.
|
Full Usage:
renderAsNamedTypeImpl withOption ctx typedName
Parameters:
bool
-
ctx : GeneratorContext
-
typedName : TypedNameRender
-
Returns: WidgetBuilder<Type>
|
Renders a typed name as a type signature (ie, a named type parameter in a delegate or abstract member).
You can enable or disable the rendering of the optionality in the type, or in the name instead using
the
|
Full Usage:
renderAsNamedTypeWithOptionName ctx typedName
Parameters:
GeneratorContext
-
typedName : TypedNameRender
-
Returns: WidgetBuilder<Type>
|
Render a typed name render as a type signature, with the option name rendered instead of wrapping the type with option.
|
Full Usage:
renderAsPattern ctx typedName
Parameters:
GeneratorContext
-
typedName : TypedNameRender
-
Returns: WidgetBuilder<Pattern>
|
Renders a typed name as a parameter pattern. Any optionality in the type ref or the type name render will result in the type being wrapped in option.
|
Full Usage:
renderAsPatternWithOptionName ctx typedName
Parameters:
GeneratorContext
-
typedName : TypedNameRender
-
Returns: WidgetBuilder<Pattern>
|
Renders a typed name as a parameter pattern. Will route any nullability in the typed name render or the type ref to the parameter name.
|
Full Usage:
renderBinding ctx typedName
Parameters:
GeneratorContext
typedName : TypedNameRender
Returns: WidgetBuilder<BindingNode>
|
|
Full Usage:
renderMember ctx typedName
Parameters:
GeneratorContext
typedName : TypedNameRender
Returns: WidgetBuilder<MemberDefn>
|
|
Full Usage:
renderTypeOnly ctx typedName
Parameters:
GeneratorContext
typedName : TypedNameRender
Returns: WidgetBuilder<Type>
|
|
Full Usage:
renderValMember ctx typedName anchorPath
Parameters:
GeneratorContext
typedName : TypedNameRender
anchorPath : 'a
Returns: WidgetBuilder<MemberDefn>
Type parameters: 'a |
|