NamePath Module
Types and nested modules
| Type/Module | Description |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Builder for constructing paths with easily identifiable syntax (originally made for spec testing, but
may be a useful abstraction for consumers who need to create paths for injected types or other purposes).
And a transient path would be:
If you do not pass a string to the transient builder, it will be anchored.
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Functions and values
| Function or value |
Description
|
|
Builder for constructing paths with easily identifiable syntax (originally made for spec testing, but
may be a useful abstraction for consumers who need to create paths for injected types or other purposes).
And a transient path would be:
If you do not pass a string to the transient builder, it will be anchored.
|