PathBuilder Type
Builder for constructing paths with easily identifiable syntax (originally made for spec testing, but
may be a useful abstraction for consumers who need to create paths for injected types or other purposes).
All concrete paths are preceded by a single _, while transient paths are preceded and followed by _.
Therefor making a concrete path would be:
_module "Root"; _module "Module"; _type "Type"
And a transient path would be:
_module_ "Root"; _type_ "Type"
If you do not pass a string to the transient builder, it will be anchored.
_type_ // TransientTypePath.Anchored
_type_ "Type" // TransientTypePath.AnchoredAndMoored "Type"
_module_ "Module"; _type_ "Type" // TransientTypePath.Moored(TransientModulePath.AnchoredAndMoored "Module", "Type")
Constructors
| Constructor |
Description
|
|
|
Instance members
| Instance member |
Description
|
Full Usage:
asAnchorPath
Returns: AnchorPath
Modifiers: inline Type parameters: ^a (requires (static member Create : ^a -> Xantham.Generator.NamePath.AnchorPath)) |
|
|
|
Full Usage:
asTransientPath
Returns: TransientPath
Modifiers: inline Type parameters: ^a (requires (static member Create : ^a -> Xantham.Generator.NamePath.TransientPath)) |
|
Full Usage:
this.Combine
Parameters:
TransientMemberPath
b : string
Returns: TransientParameterPath
Modifiers: inline |
|
Full Usage:
this.Combine
Parameters:
TransientTypePath
b : string
Returns: TransientMemberPath
Modifiers: inline |
|
Full Usage:
this.Combine
Parameters:
TransientModulePath
b : string
Returns: TransientModulePath
Modifiers: inline |
|
Full Usage:
this.Combine
Parameters:
ParameterPath
b : Name<MeasureProduct<typar, MeasureOne>>
Returns: TypeParamPath
Modifiers: inline |
|
Full Usage:
this.Combine
Parameters:
MemberPath
b : Name<MeasureProduct<typar, MeasureOne>>
Returns: TypeParamPath
Modifiers: inline |
|
Full Usage:
this.Combine
Parameters:
TypePath
b : Name<MeasureProduct<typar, MeasureOne>>
Returns: TypeParamPath
Modifiers: inline |
|
Full Usage:
this.Combine
Parameters:
MemberPath
b : string
Returns: ParameterPath
Modifiers: inline |
|
|
|
|
|
Full Usage:
this.Combine
Parameters:
ModulePath
b : string
Returns: ModulePath
Modifiers: inline |
|
Full Usage:
this.Combine
Parameters:
'a
b : unit
Returns: 'a
Modifiers: inline Type parameters: 'a |
|
Full Usage:
this.Delay
Parameters:
unit -> 'a
Returns: 'a
Modifiers: inline Type parameters: 'a |
|
Full Usage:
this.For
Parameters:
ModulePath
b : unit -> string
Returns: ModulePath
Modifiers: inline |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
this.Run
Parameters:
'a
Returns: 'a
Modifiers: inline Type parameters: 'a |
|
Full Usage:
this.Yield
Parameters:
string
Returns: string
Modifiers: inline |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
this.Yield
Parameters:
unit
Modifiers: inline |
|
Full Usage:
this.Zero
Modifiers: inline |
|