GroupModule Type
One module a run writes: a group's declarations under the module name that group templates to (O7).
Record fields
| Record Field |
Description
|
|
|
Full Usage:
Group
Field type: string
|
The npm name the group is addressed by under `xantham.json`'s `groups`; the entry package's own name for the entry group.
|
Full Usage:
IsEntry
Field type: bool
|
The group the run was asked to generate. Its module is written at the output root; every other shipped group is written under `groups/`.
|
Full Usage:
Module
Field type: string
|
|
Full Usage:
RuntimePackage
Field type: string
|
The npm package this module's `[
|