Exports Module
Functions and values
| Function or value |
Description
|
|
`Exports` members from the value exports that are not classes: functions (every overload emitted), and values - `const`/`let`/`var` and namespace objects - as properties, settable where the value is a mutable global.
|