Ordering Module
Functions and values
| Function or value |
Description
|
|
Fixes the output order the renderer will follow verbatim: declarations in source order with name as the tiebreak, then the `Exports` type - its members in harvest order - last.
|