RenderScopeStore Module
The strategy here is to force references being created with a contract that would recognise and register any transient type paths that are defined.
Nested modules
| Modules | Description |
|
|
|
|
|
|
|
|
|
|
|
Functions and values
| Function or value |
Description
|
Full Usage:
appendNameToPathContext scope name
Parameters:
RenderScopeStore
name : Name<'u>
Returns: RenderScopeStore
Type parameters: 'u |
|
Full Usage:
appendStringToPathContext scope str
Parameters:
RenderScopeStore
str : string
Returns: RenderScopeStore
|
|
|
|
Full Usage:
mapPathContext fn scope
Parameters:
TransientPath -> TransientPath
scope : RenderScopeStore
Returns: RenderScopeStore
|
|
Full Usage:
tryAdd resolvedType transientTypePath scope
Parameters:
ResolvedType
transientTypePath : TransientTypePath
scope : RenderScopeStore
|
|