UnionBuilder Type
A builder for WidgetBuilder<Type>s that represent erased unions in Fable.
It tracks the lengths of the unions it builds to ensure that we have all erased unions defined in the base set,
otherwise we can generate our own.
Constructors
| Constructor |
Description
|
Full Usage:
UnionBuilder(maxLengthExisting)
Parameters:
int
Returns: UnionBuilder
|
|
Instance members
| Instance member |
Description
|
Full Usage:
this.Combine
Parameters:
WidgetBuilder<Type> list
r : WidgetBuilder<Type> list
Returns: WidgetBuilder<Type> list
|
|
Full Usage:
this.Delay
Parameters:
unit -> WidgetBuilder<Type> list
Returns: WidgetBuilder<Type> list
|
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
this.YieldFrom
Parameters:
WidgetBuilder<Type> list
Returns: WidgetBuilder<Type> list
|
|