TsFunction Type
Represents a top-level (or exported) function declaration with its type and generics.
Reflects: `FunctionDeclaration` and its `Signature`.
Example (TS):
```ts
export function sum
Record fields
| Record Field |
Description
|
|
|
Full Usage:
FullyQualifiedName
Field type: string list
|
|
Full Usage:
IsDeclared
Field type: bool
|
|
Full Usage:
Name
Field type: string
|
|
|
|
|
The type key or signature key of the function's signature. This key should return a type literal with call signatures.
|
Full Usage:
Field type: string option
|
|
|
|
|
|