TsTypeQuery Type
Represents a type query like `typeof Foo` or `typeof Foo.bar`. The type query is resolved to the type of the referenced entity.
The name is provided so that enum like type query unions can have
names inferred from the query appropriately.
This is the cheapest schema representation.
Record fields
| Record Field |
Description
|
Full Usage:
FullyQualifiedName
Field type: string list
|
|
|