Accessors Module
Typed child and data access, one module per node type. These are the `AstNode` accessors with the argument and the result typed, which is the whole difference: `AstNode.IfStatement.thenStatement` will read slot 1 of anything you hand it, and `IfStatement.thenStatement` will not compile unless you hand it one.
Nested modules
| Modules | Description |
|
Children of `ArrayLiteralExpression`. |
|
|
Children of `ArrayTypeNode`. |
|
|
Children of `ArrowFunction`. |
|
|
Children of `AsExpression`. |
|
|
Children of `AwaitExpression`. |
|
|
Data of `BigIntLiteral`, which has no children. |
|
|
Children of `BinaryExpression`. |
|
|
Children of `BindingElement`. |
|
|
Children of `BindingPattern`. |
|
|
Children of `Block`. |
|
|
Children of `BreakStatement`. |
|
|
Children of `CallExpression`. |
|
|
Children of `CallSignatureDeclaration`. |
|
|
Children of `CaseBlock`. |
|
|
Children of `CaseOrDefaultClause`. |
|
|
Children of `CatchClause`. |
|
|
Children of `ClassDeclaration`. |
|
|
Children of `ClassExpression`. |
|
|
Children of `ClassStaticBlockDeclaration`. |
|
|
Children of `ComputedPropertyName`. |
|
|
Children of `ConditionalExpression`. |
|
|
Children of `ConditionalTypeNode`. |
|
|
Children of `ConstructSignatureDeclaration`. |
|
|
Children of `ConstructorDeclaration`. |
|
|
Children of `ConstructorTypeNode`. |
|
|
Children of `ContinueStatement`. |
|
|
Children of `Decorator`. |
|
|
Children of `DeleteExpression`. |
|
|
Children of `DoStatement`. |
|
|
Children of `ElementAccessExpression`. |
|
|
Children of `EnumDeclaration`. |
|
|
Children of `EnumMember`. |
|
|
Children of `ExportAssignment`. |
|
|
Children of `ExportDeclaration`. |
|
|
Children of `ExportSpecifier`. |
|
|
Children of `ExpressionStatement`. |
|
|
Children of `ExpressionWithTypeArguments`. |
|
|
Children of `ExternalModuleReference`. |
|
|
Children of `ForInOrOfStatement`. |
|
|
Children of `ForStatement`. |
|
|
Children of `FunctionDeclaration`. |
|
|
Children of `FunctionExpression`. |
|
|
Children of `FunctionTypeNode`. |
|
|
Children of `GetAccessorDeclaration`. |
|
|
Children of `HeritageClause`. |
|
|
Data of `Identifier`, which has no children. |
|
|
Children of `IfStatement`. |
|
|
Children of `ImportAttribute`. |
|
|
Children of `ImportAttributes`. |
|
|
Children of `ImportClause`. |
|
|
Children of `ImportDeclaration`. |
|
|
Children of `ImportEqualsDeclaration`. |
|
|
Children of `ImportSpecifier`. |
|
|
Children of `ImportTypeNode`. |
|
|
Children of `IndexSignatureDeclaration`. |
|
|
Children of `IndexedAccessTypeNode`. |
|
|
Children of `InferTypeNode`. |
|
|
Children of `InterfaceDeclaration`. |
|
|
Children of `IntersectionTypeNode`. |
|
|
Children of `JSDoc`. |
|
|
Children of `JSDocAugmentsTag`. |
|
|
Children of `JSDocCallbackTag`. |
|
|
Children of `JSDocDeprecatedTag`. |
|
|
Children of `JSDocImplementsTag`. |
|
|
Children of `JSDocImportTag`. |
|
|
Children of `JSDocLink`. |
|
|
Children of `JSDocLinkCode`. |
|
|
Children of `JSDocLinkPlain`. |
|
|
Children of `JSDocNameReference`. |
|
|
Children of `JSDocNonNullableType`. |
|
|
Children of `JSDocNullableType`. |
|
|
Children of `JSDocOptionalType`. |
|
|
Children of `JSDocOverloadTag`. |
|
|
Children of `JSDocOverrideTag`. |
|
|
Children of `JSDocParameterOrPropertyTag`. |
|
|
Children of `JSDocPrivateTag`. |
|
|
Children of `JSDocProtectedTag`. |
|
|
Children of `JSDocPublicTag`. |
|
|
Children of `JSDocReadonlyTag`. |
|
|
Children of `JSDocReturnTag`. |
|
|
Children of `JSDocSatisfiesTag`. |
|
|
Children of `JSDocSeeTag`. |
|
|
Children of `JSDocSignature`. |
|
|
Children of `JSDocTemplateTag`. |
|
|
Data of `JSDocText`, which has no children. |
|
|
Children of `JSDocThisTag`. |
|
|
Children of `JSDocThrowsTag`. |
|
|
Children of `JSDocTypeExpression`. |
|
|
Children of `JSDocTypeLiteral`. |
|
|
Children of `JSDocTypeTag`. |
|
|
Children of `JSDocTypedefTag`. |
|
|
Children of `JSDocUnknownTag`. |
|
|
Children of `JSDocVariadicType`. |
|
|
Children of `JsxAttribute`. |
|
|
Children of `JsxAttributes`. |
|
|
Children of `JsxClosingElement`. |
|
|
Children of `JsxElement`. |
|
|
Children of `JsxExpression`. |
|
|
Children of `JsxFragment`. |
|
|
Children of `JsxNamespacedName`. |
|
|
Children of `JsxOpeningElement`. |
|
|
Children of `JsxSelfClosingElement`. |
|
|
Children of `JsxSpreadAttribute`. |
|
|
Data of `JsxText`, which has no children. |
|
|
Children of `LabeledStatement`. |
|
|
Children of `LiteralTypeNode`. |
|
|
Children of `MappedTypeNode`. |
|
|
Children of `MetaProperty`. |
|
|
Children of `MethodDeclaration`. |
|
|
Children of `MethodSignatureDeclaration`. |
|
|
Children of `MissingDeclaration`. |
|
|
Children of `ModuleBlock`. |
|
|
Children of `ModuleDeclaration`. |
|
|
Children of `NamedExports`. |
|
|
Children of `NamedImports`. |
|
|
Children of `NamedTupleMember`. |
|
|
Children of `NamespaceExport`. |
|
|
Children of `NamespaceExportDeclaration`. |
|
|
Children of `NamespaceImport`. |
|
|
Children of `NewExpression`. |
|
|
Data of `NoSubstitutionTemplateLiteral`, which has no children. |
|
|
Children of `NonNullExpression`. |
|
|
Data of `NumericLiteral`, which has no children. |
|
|
Children of `ObjectLiteralExpression`. |
|
|
Children of `OptionalTypeNode`. |
|
|
Children of `ParameterDeclaration`. |
|
|
Children of `ParenthesizedExpression`. |
|
|
Children of `ParenthesizedTypeNode`. |
|
|
Children of `PartiallyEmittedExpression`. |
|
|
Children of `PostfixUnaryExpression`. |
|
|
Children of `PrefixUnaryExpression`. |
|
|
Data of `PrivateIdentifier`, which has no children. |
|
|
Children of `PropertyAccessExpression`. |
|
|
Children of `PropertyAssignment`. |
|
|
Children of `PropertyDeclaration`. |
|
|
Children of `PropertySignatureDeclaration`. |
|
|
Children of `QualifiedName`. |
|
|
Data of `RegularExpressionLiteral`, which has no children. |
|
|
Children of `RestTypeNode`. |
|
|
Children of `ReturnStatement`. |
|
|
Children of `SatisfiesExpression`. |
|
|
Children of `SetAccessorDeclaration`. |
|
|
Children of `ShorthandPropertyAssignment`. |
|
|
Children of `SourceFile`. |
|
|
Children of `SpreadAssignment`. |
|
|
Children of `SpreadElement`. |
|
|
Data of `StringLiteral`, which has no children. |
|
|
Children of `SwitchStatement`. |
|
|
Children of `SyntaxList`. |
|
|
Children of `SyntheticExpression`. |
|
|
Children of `SyntheticReferenceExpression`. |
|
|
Children of `TaggedTemplateExpression`. |
|
|
Children of `TemplateExpression`. |
|
|
Data of `TemplateHead`, which has no children. |
|
|
Children of `TemplateLiteralTypeNode`. |
|
|
Children of `TemplateLiteralTypeSpan`. |
|
|
Data of `TemplateMiddle`, which has no children. |
|
|
Children of `TemplateSpan`. |
|
|
Data of `TemplateTail`, which has no children. |
|
|
Children of `ThrowStatement`. |
|
|
Children of `TryStatement`. |
|
|
Children of `TupleTypeNode`. |
|
|
Children of `TypeAliasDeclaration`. |
|
|
Children of `TypeAssertion`. |
|
|
Children of `TypeLiteralNode`. |
|
|
Children of `TypeOfExpression`. |
|
|
Children of `TypeOperatorNode`. |
|
|
Children of `TypeParameterDeclaration`. |
|
|
Children of `TypePredicateNode`. |
|
|
Children of `TypeQueryNode`. |
|
|
Children of `TypeReferenceNode`. |
|
|
Children of `UnionTypeNode`. |
|
|
Children of `VariableDeclaration`. |
|
|
Children of `VariableDeclarationList`. |
|
|
Children of `VariableStatement`. |
|
|
Children of `VoidExpression`. |
|
|
Children of `WhileStatement`. |
|
|
Children of `WithStatement`. |
|
|
Children of `YieldExpression`. |