NumericLiteral Module
Data of `NumericLiteral`, which has no children.
Functions and values
| Function or value |
Description
|
Full Usage:
NumericLiteral.text node
Parameters:
Node<NumericLiteral>
Returns: string voption
|
The `NumericLiteral`'s text, cooked rather than as spelled in the source.
|
Full Usage:
NumericLiteral.tokenFlags node
Parameters:
Node<NumericLiteral>
Returns: TokenFlags voption
|
The literal's `TokenFlags` - the only way back to how it was spelled.
|