RegularExpressionLiteral Module
Data of `RegularExpressionLiteral`, which has no children.
Functions and values
| Function or value |
Description
|
Full Usage:
RegularExpressionLiteral.text node
Parameters:
Node<RegularExpressionLiteral>
Returns: string voption
|
The `RegularExpressionLiteral`'s text, cooked rather than as spelled in the source.
|
Full Usage:
RegularExpressionLiteral.tokenFlags node
Parameters:
Node<RegularExpressionLiteral>
Returns: TokenFlags voption
|
The literal's `TokenFlags` - the only way back to how it was spelled.
|