Ast.SpanMapSegment Type
One mapping between a virtual file and the original it was extracted from.
Record fields
| Record Field |
Description
|
|
Absent when the compiler wrote a five-element segment.
Absent is not "no features": the reference client reads a segment with no sixth
element as
|
|
|
Full Usage:
OriginalLength
Field type: int
|
|
Full Usage:
OriginalStart
Field type: int
|
|
Full Usage:
VirtualLength
Field type: int
|
|
Full Usage:
VirtualStart
Field type: int
|
|