AsyncSessionExtensions Type
The mirror of `SessionExtensions` over `TscMailbox`: same names, same arguments, each result wrapped in `Async`. Calls that overlap in time are collected into a single round trip.
Static members
| Static member |
Description
|
Full Usage:
AsyncSessionExtensions.emit (this, ?emitOnly)
Parameters:
Session<TscMailbox>
?emitOnly : int
Returns: Async<EmitResponse>
|
|
Full Usage:
AsyncSessionExtensions.emitToString (this, ?emitOnly)
Parameters:
Session<TscMailbox>
?emitOnly : int
Returns: Async<EmitOutputResponse>
|
|
Full Usage:
AsyncSessionExtensions.formatNodeForInsertion (this, file, position, data)
Parameters:
Session<TscMailbox>
file : DocumentIdentifier
position : int
data : string
Returns: Async<string>
|
|
Full Usage:
AsyncSessionExtensions.getAliasSymbolOfType (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<SymbolResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getAliasTypeArgumentsOfType (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getAliasedSymbol (this, symbol)
Parameters:
Session<TscMailbox>
symbol : int
Returns: Async<SymbolResponse>
|
|
Full Usage:
AsyncSessionExtensions.getAnyType this
Parameters:
Session<TscMailbox>
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getApparentPropertiesOfType (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<SymbolResponse[]>
|
|
Full Usage:
AsyncSessionExtensions.getApparentType (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getBaseConstraintOfType (this, type)
Parameters:
Session<TscMailbox>
type : int
Returns: Async<TypeResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getBaseTypeOfLiteralType (this, type)
Parameters:
Session<TscMailbox>
type : int
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getBaseTypeOfType (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getBaseTypes (this, type)
Parameters:
Session<TscMailbox>
type : int
Returns: Async<TypeResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getBigIntType this
Parameters:
Session<TscMailbox>
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getBindDiagnostics (this, ?files)
Parameters:
Session<TscMailbox>
?files : DocumentIdentifier[]
Returns: Async<DiagnosticResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getBooleanType this
Parameters:
Session<TscMailbox>
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getCheckTypeOfType (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getCompletionsAtPosition (this, file, position, ?triggerCharacter, ?includeSymbol)
Parameters:
Session<TscMailbox>
file : DocumentIdentifier
position : int
?triggerCharacter : string
?includeSymbol : bool
Returns: Async<CompletionInfoResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getConfigFileNames this
Parameters:
Session<TscMailbox>
Returns: Async<string[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getConfigFileParsingDiagnostics this
Parameters:
Session<TscMailbox>
Returns: Async<DiagnosticResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getConfigSourceFile (this, file)
Parameters:
Session<TscMailbox>
file : DocumentIdentifier
Returns: Async<SourceFile voption>
|
|
Full Usage:
AsyncSessionExtensions.getConstantValue (this, location)
Parameters:
Session<TscMailbox>
location : string
Returns: Async<JsonNode voption>
|
|
Full Usage:
AsyncSessionExtensions.getConstraintOfType (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getConstraintOfTypeParameter (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getContextualType (this, location)
Parameters:
Session<TscMailbox>
location : string
Returns: Async<TypeResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getDeclarationDiagnostics (this, ?files)
Parameters:
Session<TscMailbox>
?files : DocumentIdentifier[]
Returns: Async<DiagnosticResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getDeclarationEmit (this, ?files)
Parameters:
Session<TscMailbox>
?files : DocumentIdentifier[]
Returns: Async<EmitOutputResponse>
|
|
Full Usage:
AsyncSessionExtensions.getDeclaredTypeOfSymbol (this, symbol)
Parameters:
Session<TscMailbox>
symbol : int
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getDefaultFromTypeParameter (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getDefaultProjectForFile (this, file)
Parameters:
Session<TscMailbox>
file : DocumentIdentifier
Returns: Async<ProjectResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getDocumentationComment (this, symbol)
Parameters:
Session<TscMailbox>
symbol : int
Returns: Async<string>
|
|
Full Usage:
AsyncSessionExtensions.getESSymbolType this
Parameters:
Session<TscMailbox>
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getExportSpecifierLocalTargetSymbol (this, location)
Parameters:
Session<TscMailbox>
location : string
Returns: Async<SymbolResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getExportSymbolOfSymbol (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<SymbolResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getExportsOfModule (this, symbol)
Parameters:
Session<TscMailbox>
symbol : int
Returns: Async<SymbolResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getExportsOfSymbol (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<SymbolResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getExtendsTypeOfType (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getFalseTypeOfConditionalType (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getFreshTypeOfType (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getFullyQualifiedName (this, symbol)
Parameters:
Session<TscMailbox>
symbol : int
Returns: Async<string>
|
|
Full Usage:
AsyncSessionExtensions.getGlobalDiagnostics this
Parameters:
Session<TscMailbox>
Returns: Async<DiagnosticResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getImmediateAliasedSymbol (this, symbol)
Parameters:
Session<TscMailbox>
symbol : int
Returns: Async<SymbolResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getImportAdderEdits (this, file, ?actions)
Parameters:
Session<TscMailbox>
file : DocumentIdentifier
?actions : ImportAdderAction[]
Returns: Async<TextEdit[]>
|
|
Full Usage:
AsyncSessionExtensions.getIndexInfosOfType (this, type)
Parameters:
Session<TscMailbox>
type : int
Returns: Async<IndexInfoResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getIndexTypeOfType (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getJavaScriptEmit (this, ?files)
Parameters:
Session<TscMailbox>
?files : DocumentIdentifier[]
Returns: Async<EmitOutputResponse>
|
|
Full Usage:
AsyncSessionExtensions.getJsDocTags (this, symbol)
Parameters:
Session<TscMailbox>
symbol : int
Returns: Async<JSDocTagInfo[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getLocalTypeParametersOfType (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getMemberInModuleExports (this, symbol, name)
Parameters:
Session<TscMailbox>
symbol : int
name : string
Returns: Async<SymbolResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getMembersOfSymbol (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<SymbolResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getNeverType this
Parameters:
Session<TscMailbox>
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getNonMissingTypeOfSymbol (this, symbol)
Parameters:
Session<TscMailbox>
symbol : int
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getNonNullableType (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getNonPrimitiveType this
Parameters:
Session<TscMailbox>
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getNullType this
Parameters:
Session<TscMailbox>
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getNumberType this
Parameters:
Session<TscMailbox>
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getObjectTypeOfType (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getOuterTypeParametersOfType (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getParameterType (this, signature, index)
Parameters:
Session<TscMailbox>
signature : int
index : int
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getParametersOfSignature (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<SymbolResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getParentOfSymbol (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<SymbolResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getProgramDiagnostics this
Parameters:
Session<TscMailbox>
Returns: Async<DiagnosticResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getPropertiesOfType (this, type)
Parameters:
Session<TscMailbox>
type : int
Returns: Async<SymbolResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getPropertyOfType (this, type, name)
Parameters:
Session<TscMailbox>
type : int
name : string
Returns: Async<SymbolResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getReducedType (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getReferencedSymbolsForNode (this, node, position)
Parameters:
Session<TscMailbox>
node : string
position : int
Returns: Async<ReferencedSymbolEntry[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getReferencesToSymbolInFile (this, file, symbol)
Parameters:
Session<TscMailbox>
file : DocumentIdentifier
symbol : int
Returns: Async<string[]>
|
|
Full Usage:
AsyncSessionExtensions.getRegularTypeOfType (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getResolvedSignature (this, location)
Parameters:
Session<TscMailbox>
location : string
Returns: Async<SignatureResponse>
|
|
Full Usage:
AsyncSessionExtensions.getRestTypeOfSignature (this, signature)
Parameters:
Session<TscMailbox>
signature : int
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getReturnTypeOfSignature (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getSemanticDiagnostics (this, ?files)
Parameters:
Session<TscMailbox>
?files : DocumentIdentifier[]
Returns: Async<DiagnosticResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getShorthandAssignmentValueSymbol (this, location)
Parameters:
Session<TscMailbox>
location : string
Returns: Async<SymbolResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getSignatureFromDeclaration (this, location)
Parameters:
Session<TscMailbox>
location : string
Returns: Async<SignatureResponse>
|
|
Full Usage:
AsyncSessionExtensions.getSignatureUsages (this, signatureDecl)
Parameters:
Session<TscMailbox>
signatureDecl : string
Returns: Async<SignatureUsageResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getSignaturesOfType (this, type, kind)
Parameters:
Session<TscMailbox>
type : int
kind : SignatureKind
Returns: Async<SignatureResponse[]>
|
|
Full Usage:
AsyncSessionExtensions.getSourceFile (this, file)
Parameters:
Session<TscMailbox>
file : DocumentIdentifier
Returns: Async<SourceFile voption>
|
|
Full Usage:
AsyncSessionExtensions.getSourceFileMetadata (this, file)
Parameters:
Session<TscMailbox>
file : DocumentIdentifier
Returns: Async<SourceFileMetadata voption>
|
|
Full Usage:
AsyncSessionExtensions.getSourceFileNames this
Parameters:
Session<TscMailbox>
Returns: Async<string[]>
|
|
Full Usage:
AsyncSessionExtensions.getStringType this
Parameters:
Session<TscMailbox>
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getSuggestionDiagnostics (this, ?files)
Parameters:
Session<TscMailbox>
?files : DocumentIdentifier[]
Returns: Async<DiagnosticResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getSymbolAtLocation (this, location)
Parameters:
Session<TscMailbox>
location : string
Returns: Async<SymbolResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getSymbolAtPosition (this, file, position)
Parameters:
Session<TscMailbox>
file : DocumentIdentifier
position : int
Returns: Async<SymbolResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getSymbolOfSourceFile (this, file)
Parameters:
Session<TscMailbox>
file : DocumentIdentifier
Returns: Async<SymbolResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getSymbolOfType (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<SymbolResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getSymbolsAtLocations (this, ?locations)
Parameters:
Session<TscMailbox>
?locations : string[]
Returns: Async<SymbolResponse[]>
|
|
Full Usage:
AsyncSessionExtensions.getSymbolsAtPositions (this, file, ?positions)
Parameters:
Session<TscMailbox>
file : DocumentIdentifier
?positions : int[]
Returns: Async<SymbolResponse[]>
|
|
Full Usage:
AsyncSessionExtensions.getSymbolsInScope (this, meaning, ?location, ?file, ?position)
Parameters:
Session<TscMailbox>
meaning : SymbolFlags
?location : string
?file : DocumentIdentifier
?position : int
Returns: Async<SymbolResponse[]>
|
|
Full Usage:
AsyncSessionExtensions.getSymbolsOfSourceFiles (this, ?files)
Parameters:
Session<TscMailbox>
?files : DocumentIdentifier[]
Returns: Async<SymbolResponse[]>
|
|
Full Usage:
AsyncSessionExtensions.getSyntacticDiagnostics (this, ?files)
Parameters:
Session<TscMailbox>
?files : DocumentIdentifier[]
Returns: Async<DiagnosticResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getTargetOfSignature (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<SignatureResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getTargetOfType (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getTargetSymbol (this, symbol)
Parameters:
Session<TscMailbox>
symbol : int
Returns: Async<SymbolResponse>
|
|
Full Usage:
AsyncSessionExtensions.getThisParameterOfSignature (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<SymbolResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getTrueTypeOfConditionalType (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getTypeArguments (this, type)
Parameters:
Session<TscMailbox>
type : int
Returns: Async<TypeResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getTypeAtLocation (this, location)
Parameters:
Session<TscMailbox>
location : string
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getTypeAtLocations (this, ?locations)
Parameters:
Session<TscMailbox>
?locations : string[]
Returns: Async<TypeResponse[]>
|
|
Full Usage:
AsyncSessionExtensions.getTypeAtPosition (this, file, position)
Parameters:
Session<TscMailbox>
file : DocumentIdentifier
position : int
Returns: Async<TypeResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getTypeFromTypeNode (this, location)
Parameters:
Session<TscMailbox>
location : string
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getTypeOfSymbol (this, symbol)
Parameters:
Session<TscMailbox>
symbol : int
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getTypeOfSymbolAtLocation (this, symbol, location)
Parameters:
Session<TscMailbox>
symbol : int
location : string
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getTypeParameterAtPosition (this, signature, index)
Parameters:
Session<TscMailbox>
signature : int
index : int
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getTypeParametersOfSignature (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getTypeParametersOfType (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getTypePredicateOfSignature (this, signature)
Parameters:
Session<TscMailbox>
signature : int
Returns: Async<TypePredicateResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.getTypesAtPositions (this, file, ?positions)
Parameters:
Session<TscMailbox>
file : DocumentIdentifier
?positions : int[]
Returns: Async<TypeResponse[]>
|
|
Full Usage:
AsyncSessionExtensions.getTypesOfSymbols (this, ?symbols)
Parameters:
Session<TscMailbox>
?symbols : int[]
Returns: Async<TypeResponse[]>
|
|
Full Usage:
AsyncSessionExtensions.getTypesOfType (this, objectId)
Parameters:
Session<TscMailbox>
objectId : int
Returns: Async<TypeResponse[] voption>
|
|
Full Usage:
AsyncSessionExtensions.getUndefinedType this
Parameters:
Session<TscMailbox>
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getUnknownType this
Parameters:
Session<TscMailbox>
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getVoidType this
Parameters:
Session<TscMailbox>
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.getWellKnownSignatures this
Parameters:
Session<TscMailbox>
Returns: Async<WellKnownSignaturesResponse>
|
|
Full Usage:
AsyncSessionExtensions.getWellKnownSymbols this
Parameters:
Session<TscMailbox>
Returns: Async<WellKnownSymbolsResponse>
|
|
Full Usage:
AsyncSessionExtensions.getWidenedType (this, type)
Parameters:
Session<TscMailbox>
type : int
Returns: Async<TypeResponse>
|
|
Full Usage:
AsyncSessionExtensions.isArrayLikeType (this, type)
Parameters:
Session<TscMailbox>
type : int
Returns: Async<bool>
|
|
Full Usage:
AsyncSessionExtensions.isArrayType (this, type)
Parameters:
Session<TscMailbox>
type : int
Returns: Async<bool>
|
|
Full Usage:
AsyncSessionExtensions.isContextSensitive (this, location)
Parameters:
Session<TscMailbox>
location : string
Returns: Async<bool>
|
|
Full Usage:
AsyncSessionExtensions.isReadonlySymbol (this, symbol)
Parameters:
Session<TscMailbox>
symbol : int
Returns: Async<bool>
|
|
Full Usage:
AsyncSessionExtensions.isTypeAssignableTo (this, source, target)
Parameters:
Session<TscMailbox>
source : int
target : int
Returns: Async<bool>
|
|
Full Usage:
AsyncSessionExtensions.release this
Parameters:
Session<TscMailbox>
Returns: Async<unit>
|
|
Full Usage:
AsyncSessionExtensions.resolveName (this, name, meaning, ?location, ?file, ?position, ?excludeGlobals)
Parameters:
Session<TscMailbox>
name : string
meaning : SymbolFlags
?location : string
?file : DocumentIdentifier
?position : int
?excludeGlobals : bool
Returns: Async<SymbolResponse voption>
|
|
Full Usage:
AsyncSessionExtensions.signatureToSignatureDeclaration (this, signature, kind, ?location, ?flags)
Parameters:
Session<TscMailbox>
signature : int
kind : SyntaxKind
?location : string
?flags : NodeBuilderFlags
Returns: Async<SourceFile voption>
|
|
Full Usage:
AsyncSessionExtensions.typeToString (this, type, ?location, ?flags)
Parameters:
Session<TscMailbox>
type : int
?location : string
?flags : int
Returns: Async<JsonNode voption>
|
|
Full Usage:
AsyncSessionExtensions.typeToTypeNode (this, type, ?location, ?flags)
Parameters:
Session<TscMailbox>
type : int
?location : string
?flags : int
Returns: Async<SourceFile voption>
|
|
Full Usage:
AsyncSessionExtensions.updateTemporarySnapshot (this, file, newText)
Parameters:
Session<TscMailbox>
file : DocumentIdentifier
newText : string
Returns: Async<UpdateSnapshotResponse>
|
|