CompilerOptions Type
CompilerOptions contains the compiler options exposed by the API.
Record fields
| Record Field |
Description
|
Full Usage:
AllowArbitraryExtensions
Field type: bool voption
|
|
Full Usage:
AllowImportingTsExtensions
Field type: bool voption
|
|
Full Usage:
AllowJs
Field type: bool voption
|
|
Full Usage:
AllowNonTsExtensions
Field type: bool voption
|
|
Full Usage:
AllowUmdGlobalAccess
Field type: bool voption
|
|
Full Usage:
AllowUnreachableCode
Field type: bool voption
|
|
Full Usage:
AllowUnusedLabels
Field type: bool voption
|
|
Full Usage:
AssumeChangesOnlyAffectDirectDependencies
Field type: bool voption
|
|
Full Usage:
CheckJs
Field type: bool voption
|
|
Full Usage:
Composite
Field type: bool voption
|
|
Full Usage:
ConfigFilePath
Field type: string voption
|
Internal fields
|
Full Usage:
CustomConditions
Field type: string[] voption
|
|
Full Usage:
Declaration
Field type: bool voption
|
|
Full Usage:
DeclarationDir
Field type: string voption
|
|
Full Usage:
DeclarationMap
Field type: bool voption
|
|
Full Usage:
DeduplicatePackages
Field type: bool voption
|
|
Full Usage:
DisableReferencedProjectLoad
Field type: bool voption
|
|
Full Usage:
DisableSizeLimit
Field type: bool voption
|
|
Full Usage:
DisableSolutionSearching
Field type: bool voption
|
|
Full Usage:
DisableSourceOfProjectReferenceRedirect
Field type: bool voption
|
|
Full Usage:
EmitBOM
Field type: bool voption
|
|
Full Usage:
EmitDeclarationOnly
Field type: bool voption
|
|
Full Usage:
EmitDecoratorMetadata
Field type: bool voption
|
|
Full Usage:
ErasableSyntaxOnly
Field type: bool voption
|
|
Full Usage:
ExactOptionalPropertyTypes
Field type: bool voption
|
|
Full Usage:
ExperimentalDecorators
Field type: bool voption
|
|
Full Usage:
ForceConsistentCasingInFileNames
Field type: bool voption
|
|
Full Usage:
IgnoreConfig
Field type: bool voption
|
|
Full Usage:
IgnoreDeprecations
Field type: string voption
|
|
Full Usage:
ImportHelpers
Field type: bool voption
|
|
Full Usage:
Incremental
Field type: bool voption
|
|
Full Usage:
Init
Field type: bool voption
|
|
Full Usage:
InlineSourceMap
Field type: bool voption
|
|
Full Usage:
InlineSources
Field type: bool voption
|
|
Full Usage:
IsolatedDeclarations
Field type: bool voption
|
|
Full Usage:
IsolatedModules
Field type: bool voption
|
|
|
|
Full Usage:
JsxFactory
Field type: string voption
|
|
Full Usage:
JsxFragmentFactory
Field type: string voption
|
|
Full Usage:
JsxImportSource
Field type: string voption
|
|
Full Usage:
Lib
Field type: string[] voption
|
|
Full Usage:
LibReplacement
Field type: bool voption
|
|
Full Usage:
Locale
Field type: string voption
|
|
Full Usage:
MapRoot
Field type: string voption
|
|
Full Usage:
MaxNodeModuleJsDepth
Field type: int voption
|
|
|
|
|
|
|
|
Full Usage:
ModuleSuffixes
Field type: string[] voption
|
|
|
|
Full Usage:
NoCheck
Field type: bool voption
|
|
Full Usage:
NoEmit
Field type: bool voption
|
|
Full Usage:
NoEmitHelpers
Field type: bool voption
|
|
Full Usage:
NoEmitOnError
Field type: bool voption
|
|
Full Usage:
NoErrorTruncation
Field type: bool voption
|
|
Full Usage:
NoFallthroughCasesInSwitch
Field type: bool voption
|
|
Full Usage:
NoImplicitAny
Field type: bool voption
|
|
Full Usage:
NoImplicitOverride
Field type: bool voption
|
|
Full Usage:
NoImplicitReturns
Field type: bool voption
|
|
Full Usage:
NoImplicitThis
Field type: bool voption
|
|
Full Usage:
NoLib
Field type: bool voption
|
|
Full Usage:
NoPropertyAccessFromIndexSignature
Field type: bool voption
|
|
Full Usage:
NoResolve
Field type: bool voption
|
|
Full Usage:
NoUncheckedIndexedAccess
Field type: bool voption
|
|
Full Usage:
NoUncheckedSideEffectImports
Field type: bool voption
|
|
Full Usage:
NoUnusedLocals
Field type: bool voption
|
|
Full Usage:
NoUnusedParameters
Field type: bool voption
|
|
Full Usage:
OutDir
Field type: string voption
|
|
|
|
Full Usage:
PreserveConstEnums
Field type: bool voption
|
|
Full Usage:
PreserveSymlinks
Field type: bool voption
|
|
Full Usage:
Project
Field type: string voption
|
|
Full Usage:
ReactNamespace
Field type: string voption
|
|
Full Usage:
RemoveComments
Field type: bool voption
|
|
Full Usage:
ResolveJsonModule
Field type: bool voption
|
|
Full Usage:
ResolvePackageJsonExports
Field type: bool voption
|
|
Full Usage:
ResolvePackageJsonImports
Field type: bool voption
|
|
Full Usage:
RewriteRelativeImportExtensions
Field type: bool voption
|
|
Full Usage:
RootDir
Field type: string voption
|
|
Full Usage:
RootDirs
Field type: string[] voption
|
|
Full Usage:
SkipDefaultLibCheck
Field type: bool voption
|
|
Full Usage:
SkipLibCheck
Field type: bool voption
|
|
Full Usage:
SourceMap
Field type: bool voption
|
|
Full Usage:
SourceRoot
Field type: string voption
|
|
Full Usage:
StableTypeOrdering
Field type: bool voption
|
|
Full Usage:
Strict
Field type: bool voption
|
|
Full Usage:
StrictBindCallApply
Field type: bool voption
|
|
Full Usage:
StrictBuiltinIteratorReturn
Field type: bool voption
|
|
Full Usage:
StrictFunctionTypes
Field type: bool voption
|
|
Full Usage:
StrictNullChecks
Field type: bool voption
|
|
Full Usage:
StrictPropertyInitialization
Field type: bool voption
|
|
Full Usage:
StripInternal
Field type: bool voption
|
|
Full Usage:
SuppressOutputPathCheck
Field type: bool voption
|
|
|
|
Full Usage:
TraceResolution
Field type: bool voption
|
|
Full Usage:
TsBuildInfoFile
Field type: string voption
|
|
Full Usage:
TypeRoots
Field type: string[] voption
|
|
Full Usage:
Types
Field type: string[] voption
|
|
Full Usage:
UseDefineForClassFields
Field type: bool voption
|
|
Full Usage:
UseUnknownInCatchVariables
Field type: bool voption
|
|
Full Usage:
VerbatimModuleSyntax
Field type: bool voption
|
|
Static members
| Static member |
Description
|
|
The record with nothing set: every field is either optional or a default of its own, so this serialises to `{}`. Copy-update it to fill in the fields you mean - `{ CompilerOptions.Default with ... }` - rather than writing all 101 out.
|