DiagnosticResponse Type
DiagnosticResponse is the API response for a single diagnostic.
Record fields
| Record Field |
Description
|
Full Usage:
Category
Field type: int
|
Category is the diagnostic category (error, warning, suggestion, message).
|
Full Usage:
Code
Field type: int
|
Code is the diagnostic error code.
|
Full Usage:
End
Field type: int
|
End is the end position of the diagnostic in the source file.
|
|
EndPosition is the zero-based line and UTF-16 character position of End.
|
Full Usage:
FileName
Field type: string voption
|
FileName is the path of the file this diagnostic belongs to, if any.
|
|
MessageChain contains chained diagnostic messages, if any.
|
Full Usage:
Pos
Field type: int
|
Pos is the start position of the diagnostic in the source file.
|
|
RelatedInformation contains related diagnostic information, if any.
|
Full Usage:
ReportsDeprecated
Field type: bool voption
|
ReportsDeprecated indicates this diagnostic highlights deprecated code.
|
Full Usage:
ReportsUnnecessary
Field type: bool voption
|
ReportsUnnecessary indicates this diagnostic highlights unnecessary code.
|
Full Usage:
Field type: string voption
|
Source is a custom diagnostic-code prefix. An empty value uses the default "TS".
|
|
SourceLines contains the source lines needed to render this diagnostic with context.
|
|
StartPosition is the zero-based line and UTF-16 character position of Pos.
|
Full Usage:
Text
Field type: string
|
Text is the localized diagnostic message text.
|