ProjectReference Type
Path is a normalized path on disk.
Record fields
| Record Field |
Description
|
Full Usage:
Circular
Field type: bool
|
Circular indicates that this reference is intended to form a circularity.
|
Full Usage:
OriginalPath
Field type: string
|
OriginalPath is the path as it was originally written.
|
Full Usage:
Path
Field type: string
|
Path is a normalized path on disk.
|