SymbolResponse Type
Project is the project in which the symbol was first observed. It is the default project for follow-up lookups whose results can vary by project.
Record fields
| Record Field |
Description
|
|
|
Full Usage:
Declarations
Field type: string[] voption
|
|
Full Usage:
ExportSymbol
Field type: int voption
|
|
|
|
Full Usage:
Id
Field type: int
|
|
Full Usage:
Name
Field type: string
|
|
Full Usage:
Parent
Field type: int voption
|
|
Full Usage:
Project
Field type: string
|
Project is the project in which the symbol was first observed. It is the default project for follow-up lookups whose results can vary by project.
|
Full Usage:
ValueDeclaration
Field type: string voption
|
|