TypeResponse Type
Value is literal type data. BigInt literals are encoded as signed decimal strings because JSON cannot represent bigint; absent values are null.
Record fields
| Record Field |
Description
|
Full Usage:
AliasSymbol
Field type: int voption
|
|
Full Usage:
AliasTypeArguments
Field type: int[] voption
|
TypeAlias data
|
Full Usage:
BaseType
Field type: int voption
|
SubstitutionType data
|
Full Usage:
CheckType
Field type: int voption
|
ConditionalType data
|
|
TupleType data
|
Full Usage:
ExtendsType
Field type: int voption
|
|
Full Usage:
FixedLength
Field type: int voption
|
|
|
|
Full Usage:
FreshType
Field type: int voption
|
FreshableType data (LiteralType and computed enum types)
|
Full Usage:
Id
Field type: int
|
|
Full Usage:
IndexType
Field type: int voption
|
|
Full Usage:
IntrinsicName
Field type: string voption
|
IntrinsicType data
|
Full Usage:
IsThisType
Field type: bool voption
|
TypeParameter data
|
Full Usage:
IsTupleType
Field type: bool voption
|
|
Full Usage:
LabeledElementDeclarations
Field type: string[] voption
|
|
Full Usage:
LocalTypeParameters
Field type: int[] voption
|
|
|
|
Full Usage:
ObjectType
Field type: int voption
|
IndexedAccessType data
|
Full Usage:
OuterTypeParameters
Field type: int[] voption
|
|
Full Usage:
Readonly
Field type: bool voption
|
|
Full Usage:
RegularType
Field type: int voption
|
|
Full Usage:
SubstConstraint
Field type: int voption
|
|
Full Usage:
Symbol
Field type: int voption
|
Symbol associated with structured types
|
Full Usage:
Target
Field type: int voption
|
ObjectType / TypeReference / StringMappingType / IndexType target
|
Full Usage:
Texts
Field type: string[] voption
|
TemplateLiteralType text segments
|
Full Usage:
TypeParameters
Field type: int[] voption
|
InterfaceType type parameters
|
Value is literal type data. BigInt literals are encoded as signed decimal strings because JSON cannot represent bigint; absent values are null.
|