UpdateSnapshotResponse Type
UpdateSnapshotResponse is returned by updateSnapshot.
Record fields
| Record Field |
Description
|
|
Changes describes source file differences from the previous snapshot. Nil for the first snapshot in a session.
|
|
Projects is the list of projects in the snapshot.
|
Full Usage:
Snapshot
Field type: int
|
Snapshot is the handle for the newly created snapshot.
|