UpdateTemporarySnapshotParams Type
UpdateTemporarySnapshotParams are the parameters for creating a temporary snapshot that overrides a single file's content.
Record fields
| Record Field |
Description
|
|
File identifies the file whose content is temporarily overridden.
|
Full Usage:
NewText
Field type: string
|
NewText is the temporary content for the file.
|
Full Usage:
Snapshot
Field type: int
|
Snapshot is the current client snapshot on which to layer the temporary update.
|